// Endogenous Variables
var 
c                 // total consumption
l                 // aggregate employment
v                 // aggregate vacancies
w                 // wage
k                 // aggregate capital
ik                // investment in physical capital
zc                // job-productivity cutoff
q                 // probability of filling a vacancy
m                 // matches
s                 // job-finding probability
u                 // unemployment rate
zav               // average job productivity
rho               // endogenous separation rate
mpl               // marginal product of labor
mpk               // marginal product of capital
phi               // value of a match to the firm
surplusF          // firm surplus
surplusW          // worker surplus
oo                // value of unemployment
wzc               // wage marginal worker
y                 // aggregate output
rk                // real rate for capital
mc                // marginal cost
multR             // investment lagrange multiplier
adjI              // investment adjustment cost  
e                 // firm value
d                 // per-period firm profit
N                 // number of producers
Ne                // number of new entrants
rpD               // relative price 
elasticity        // elasticity of substitution
markup            // markup
yfirm             // firm output
yn                // firm production funtion
vfirm             // firm vacancies
lfirm             // firm employment
kfirm             // firm capital
Util              // household's utility
Welf              // household's welfare
uc                // marginal utility of consumption
zavInt            // integral to compute average job productivity
mplzc             // marginal product of marginal worker
seprate           // separation rate
cm                // market consumption
ie                // investment in new products 
z                 // aggregate productivity
gdpIncome         // GDP Income
gdpIncomedata     // GDP Income data-consistent
cmdata            // market consumption data-consistent
ikdata            // investment in physical capital data-consistent
iedata            // investment in new products data-consistent 
wdata             // wage data-consistent
cdata             // total consumption data-consistent
ub                // unemployment benefit
fc                // firing cost
fr                // sunk entry cost regulation
;


// Innovations
varexo epsZ; 

parameters   gammaP betaP rhozP stdzP lambdaP etaP epsP meanziP stdziP alphaP piP adjIP deltafP  NbarP sigmaMuP chiP vcP fetechP deltakP shapeP exponenpfP fetechtarget hpP rrRateP phiP chi,
           c_SS l_SS v_SS w_SS  k_SS ik_SS zc_SS q_SS m_SS s_SS u_SS zav_SS rho_SS mpl_SS mpk_SS phi_SS surplusF_SS surplusW_SS oo_SS wzc_SS y_SS rk_SS mc_SS multR_SS adjI_SS
           e_SS d_SS N_SS Ne_SS rpD_SS elasticity_SS markup_SS yfirm_SS yn_SS vfirm_SS lfirm_SS kfirm_SS uc_SS  zavInt_SS
           surplusFzc_SS surplusWzc_SS phizc_SS mplzc_SS cm_SS ub_SS fc_SS fr_SS z_SS gdpIncome_SS gdpIncomedata_SS
           c_SSinit l_SSinit  k_SSinit q_SSinit  N_SSinit Ne_SSinit z_SSinit  ik_SSinit c_SSinit lfirm_SSinit vfirm_SSinit  fr_SSinit ub_SSinit fc_SSinit w_SSinit rpD_SSinit gdpIncome_SSinit gdpIncomedata_SSinit;


set_parameters_from_file('steady',M_.param_names);
set_parameters_from_file('steadyInitial',M_.param_names);
set_parameters_from_file('calibration',M_.param_names);

model;


// %---Utility Function
//Util              = log(exp(c));

Util              = log(exp(c)) - chi*(1-exp(u))^2/2;

Welf              = Util + betaP*Welf(1);

//% Labor Market Block
- exp(lfirm)      + (1-lambdaP)*(1-exp(rho))*exp(lfirm(-1)) + (1-lambdaP)*(1-exp(rho))*exp(q(-1))*exp(vfirm(-1));

- vcP/exp(q)      + (1-lambdaP)*(1-deltafP)*(betaP*exp(uc(1))/exp(uc))*((1 - exp(rho(1)))*exp(phi(1)) - exp(rho(1))*fc);  

- exp(mplzc)      + exp(wzc) - vcP/exp(q)  - fc;

- exp(surplusF)   + ( (1 - etaP)/etaP )*exp(surplusW);

- exp(wzc)        + exp(w) - etaP*(exp(mpl) - exp(mplzc)); 

- exp(yn)         + exp(z)*(exp(zav)^shapeP)*(exp(k(-1))^alphaP)*(exp(l)^(1-alphaP));

//%% Entry Block
- exp(d)          + exp(rpD)*exp(yfirm) - exp(w)*exp(lfirm) - vcP*exp(vfirm) - exp(mpk)*exp(kfirm) - exp(rho)*exp(lfirm)*fc/(1-exp(rho));  
 
- exp(e)          + (fetechP + fr) + vcP*(exp(lfirm)/exp(q) + exp(vfirm)) ;

- exp(yfirm)      + exp(yn)/exp(N);

- exp(rpD)        + exp(markup)*exp(mc);

- exp(e)          + (1 - deltafP)*betaP*(exp(uc(1))/exp(uc))*(exp(e(+1)) + exp(d(+1)));

- exp(N)          + (1 - deltafP )*(exp(N(-1)) + exp(Ne(-1)));

- 1               + exp(rpD)*((exp(.5*(NbarP - exp(N))/(sigmaMuP*NbarP*exp(N))))) ;

- exp(markup)     + exp(elasticity)/(exp(elasticity) - 1);

- exp(elasticity) + ((1 + sigmaMuP*exp(N)));

- exp(yfirm)      + (1/exp(rpD))*exp(y)/exp(N);

- exp(y)          + exp(cm) + exp(ik) + vcP*exp(v) + exp(Ne)*(fetechP + fr) + exp(rho)*exp(lfirm)*exp(N)*fc/(1-exp(rho));  


//%% Capital Accumulation 

- exp(k)          + (1 - deltakP)*exp(k(-1))   +  exp(ik)*(1 - (adjIP/2)*(adjI^2));

- exp(multR)      + (betaP*exp(uc(1))/exp(uc))*(exp(rk(1)) + (1 - deltakP)*exp(multR(1)));

- 1               + exp(multR)*((1 - (adjIP/2)*(adjI^2))  -  adjIP*adjI*(exp(ik)/exp(ik(-1))))  + adjIP*(betaP*exp(uc(1))/exp(uc))*exp(multR(1))*(adjI(1)*((exp(ik(1))/exp(ik))^2));

- adjI            + exp(ik)/exp(ik(-1)) - 1;


//% Definitions (required to solve the model)

- exp(phi)        + exp(mpl) - exp(w) + (1-lambdaP)*(1-deltafP)*(betaP*exp(uc(1))/exp(uc))*( (1-exp(rho(1)))*exp(phi(1)) - exp(rho(1))*fc(1) );  

- exp(surplusW)   + exp(w) - exp(oo) + (1-lambdaP)*(1-deltafP)*(betaP*exp(uc(1))/exp(uc))*(1-exp(rho(1)))*exp(surplusW(1)); 

//- exp(oo)         + hpP + ub  + (1-lambdaP)*(1-deltafP)*betaP*(exp(uc(1))/exp(uc))*(exp(s))*(1-exp(rho(1)))*exp(surplusW(1));

- exp(oo)         + hpP + exp(ub)  + (1-lambdaP)*(1-deltafP)*betaP*(exp(uc(1))/exp(uc))*(exp(s))*(1-exp(rho(1)))*exp(surplusW(1));

- exp(v)          + (exp(N) + exp(Ne))*exp(vfirm) + exp(Ne)*exp(lfirm)/exp(q); 

- exp(lfirm)      + exp(l)/exp(N); 

- exp(kfirm)      + exp(k(-1))/exp(N); 

- exp(m)          + (chiP*(exp(v)^(1-epsP))*(exp(u)^(epsP)));

- exp(u)          + 1 - exp(l);

- exp(s)          + exp(m)/exp(u);

- exp(q)          + exp(m)/exp(v);

- exp(zavInt)     + (-1/2*piP^(1/2)*exp(1/2*(2*meanziP+stdziP^2*shapeP)*shapeP/(1-2*alphaP+alphaP^2))*(erf(1/2*2^(1/2)/stdziP*(-log(exp(zc))+log(exp(zc))*alphaP+stdziP^2*shapeP+meanziP-meanziP*alphaP)/(-1+alphaP))-erf(1/2*2^(1/2)*(-10000000000+10000000000*alphaP+stdziP^2*shapeP+meanziP-meanziP*alphaP)/stdziP/(-1+alphaP)))*exp(-shapeP*meanziP*alphaP/(-1+alphaP)^2)/piP^(1/2))/(1-exp(rho));

- exp(zav)        + exp(zavInt)^((1 - alphaP)/shapeP);

- exp(rho)        + ((0.5 + 0.5 * erf((log(exp(zc)))/(stdziP*sqrt(2)))));

- exp(mpl)        + (1-alphaP)*exp(mc)*exp(yn)/exp(l);

- exp(mplzc)      + exp(mpl)*(exp(zc)/exp(zav))^exponenpfP;

- exp(mpk)        + alphaP*exp(mc)*exp(yn)/exp(k(-1));

- exp(surplusF)   + exp(phi) + fc;
  
- exp(rk)         + exp(mpk);

- exp(cm)         + exp(c) - hpP*(1-exp(l));

- exp(uc)         + exp(c)^-gammaP;


//% Exogenous Processes
- z               + rhozP*z(-1) - epsZ; 

//- ub              + ub_SS;

//Cycle-dependent unemployment benefits

- exp(ub)         + ub_SS + phiP*(gdpIncomedata - gdpIncomedata(-1));

- fc              + fc_SS;

- fr              + fr_SS;


//% Additional variables (not needed to solve the model)
- exp(seprate)         + lambdaP + exp(rho)*(1-lambdaP)+ deltafP*(1-lambdaP)*(1-exp(rho));//lambdaP + exp(rho)*(1-lambdaP)+ deltafP*(1-lambdaP)*(1-exp(rho));

- exp(gdpIncome)  + exp(w)*exp(l) + exp(rk)*exp(k(-1)) + exp(N)*exp(d);

- exp(ie)         + exp(Ne)*(fetechP + fr);

- exp(gdpIncomedata) + exp(gdpIncome)/exp(rpD);

- exp(cmdata)     + exp(cm)/exp(rpD);

- exp(ikdata)     + exp(ik)/exp(rpD);

- exp(wdata)      + exp(w)/exp(rpD);

- exp(cdata)      + exp(c)/exp(rpD);

- exp(iedata)     + exp(ie)/exp(rpD);

end;


initval;
//ub                  = ub_SS;
ub                  = log(ub_SS);
fc                  = fc_SS;
fr                  = fr_SS;
z                   = log(z_SS);
c                   = log(c_SS); 
l                   = log(l_SS);
u                   = log(u_SS);
q                   = log(q_SS);
s                   = log(s_SS);
v                   = log(v_SS);
m                   = log(m_SS);
mc                  = log(mc_SS);
rho                 = log(rho_SS);
zavInt              = log(zavInt_SS);
zav                 = log(zav_SS);
zc                  = log(zc_SS);
surplusF            = log(surplusF_SS);
surplusW            = log(surplusW_SS);
oo                  = log(oo_SS);
phi                 = log(phi_SS);
ik                  = log(ik_SS);
rk                  = log(rk_SS);
mpk                 = log(mpk_SS);
mpl                 = log(mpl_SS);
y                   = log(y_SS);
k                   = log(k_SS);
adjI                = adjI_SS;
multR               = log(multR_SS);
e                   = log(e_SS);
d                   = log(d_SS);
N                   = log(N_SS);
Ne                  = log(Ne_SS);
rpD                 = log(rpD_SS);
elasticity          = log(elasticity_SS);
markup              = log(markup_SS);
yfirm               = log(yfirm_SS);
yn                  = log(yn_SS);
lfirm               = log(lfirm_SS);
kfirm               = log(kfirm_SS);
vfirm               = log(vfirm_SS);
//Util                = log(c_SS);
Util                = log(exp(c)) - chi*(1-exp(u))^2/2;
Welf                = (1/(1-betaP))*Util;
uc                  = log((exp(c))^-gammaP);
w                   = log(w_SS);
mplzc               = log(exp(mpl)*(exp(zc)/exp(zav))^exponenpfP);
wzc                 = log(exp(w) - etaP*(exp(mpl) - exp(mplzc)));
seprate             = log(lambdaP + (rho_SS)*(1-lambdaP)+ deltafP*(1-lambdaP)*(1-rho_SS));
cm                  = log(cm_SS);
gdpIncome           = log(gdpIncome_SS);
cmdata              = log(exp(cm)/exp(rpD));
gdpIncomedata       = log(exp(gdpIncome)/exp(rpD));
ikdata              = log(exp(ik)/exp(rpD));
wdata               = log(exp(w)/exp(rpD));
cdata               = log(exp(c)/exp(rpD));
ie                  = log(exp(Ne)*(fetechP + fr));
iedata              = log(exp(ie)/exp(rpD));

end;


resid(1);

if max(abs(resid))>1e-10
    display('RESIDUALS IN THE CYCLE_IRF.MOD FILE ARE NOT ZERO')
    keyboard
end


shocks;
var epsZ; stderr stdzP;
end;



stoch_simul(order=1,irf=20,nograph,noprint) cmdata u ikdata gdpIncomedata wdata N iedata markup ub fr fc wdata s; 

figure(13);
/*
subplot(6,6,1);
plot(100*(cmdata_epsZ),'b','Linewidth',2);axis tight;grid on; title('Consumption');
subplot(6,6,2);
plot(100*(u_epsZ*u_SS),'b','Linewidth',2);axis tight;grid on; title('Unemployment rate');
subplot(6,6,3);
plot(100*(ikdata_epsZ),'b','Linewidth',2);axis tight;grid on; title('Investment physical capital');
subplot(6,6,4);
plot(100*(gdpIncomedata_epsZ),'b','Linewidth',2);axis tight;grid on; title('GDP');
subplot(6,6,5);
plot(100*(wdata_epsZ),'b','Linewidth',2);grid on;axis tight, title('Wage');
subplot(6,6,6);
plot(100*(N_epsZ),'b','Linewidth',2);grid on;axis tight, title('Producers');
subplot(6,6,7);
plot(100*(iedata_epsZ),'b','Linewidth',2);axis tight;grid on; title('Investment new products');
subplot(6,6,8);
plot(100*(markup_epsZ),'b','Linewidth',2);axis tight;grid on; title('Markup');
subplot(6,6,9);
plot(100*(ub_epsZ),'b','Linewidth',2);axis tight;grid on; title('Benefits');
subplot(6,6,10);
plot(100*(fr_epsZ),'b','Linewidth',2);axis tight;grid on; title('PMR');
subplot(6,6,11);
plot(100*(fc_epsZ),'b','Linewidth',2);axis tight;grid on; title('Firing costs');
subplot(6,6,12);
plot(100*(s_epsZ),'b','Linewidth',2);axis tight;grid on; title('job-finding prob.');
subplot(6,6,13);
plot(100*(thetaP_epsZ),'b','Linewidth',2);axis tight;grid on; title('labour mkt tight');
subplot(6,6,14);
plot(100*(ooption_epsZ),'b','Linewidth',2);axis tight;grid on; title('outside option');
subplot(6,6,15);
plot(100*(m_epsZ),'b','Linewidth',2);axis tight;grid on; title('matches');
subplot(6,6,16);
plot(100*(q_epsZ),'b','Linewidth',2);axis tight;grid on; title('prob. fill vacancy');
subplot(6,6,17);
plot(100*(zc_epsZ),'b','Linewidth',2);axis tight;grid on; title('prod. cut-off');
subplot(6,6,18);
plot(100*(firing_epsZ),'b','Linewidth',2);axis tight;grid on; title('firing');
subplot(6,6,19);
plot(100*(v_epsZ),'b','Linewidth',2);axis tight;grid on; title('vacancies');
subplot(6,6,20);
plot(100*(vfirm_epsZ),'b','Linewidth',2);axis tight;grid on; title('firm vac');
subplot(6,6,21);
plot(100*(lfirm_epsZ),'b','Linewidth',2);axis tight;grid on; title('firm emp');
subplot(6,6,22);
plot(100*(endosepfirm_epsZ),'b','Linewidth',2);axis tight;grid on; title('endosep firm');
subplot(6,6,23);
plot(100*(rho_epsZ),'b','Linewidth',2);axis tight;grid on; title('endo. separate');
subplot(6,6,24);
plot(100*(exosepfirm_epsZ),'b','Linewidth',2);axis tight;grid on; title('exosep firm');
subplot(6,6,25);
plot(100*(endosepAG_epsZ),'b','Linewidth',2);axis tight;grid on; title('endosep agg');
subplot(6,6,26);
plot(100*(exosepAG_epsZ),'b','Linewidth',2);axis tight;grid on; title('exosep agg');
subplot(6,6,27);
plot(100*(l_epsZ),'b','Linewidth',2);axis tight;grid on; title('emp');
subplot(6,6,28);
plot(100*(newhiresfirm_epsZ),'b','Linewidth',2);axis tight;grid on; title('firm newhires');
subplot(6,6,29);
plot(100*(newhiresAG_epsZ),'b','Linewidth',2);axis tight;grid on; title('Agg newhires');
subplot(6,6,30);
plot(100*(totsepfirm_epsZ),'b','Linewidth',2);axis tight;grid on; title('totsepfirm');
subplot(6,6,31);
plot(100*(totsepagg_epsZ),'b','Linewidth',2);axis tight;grid on; title('totsepagg');
subplot(6,6,32);
plot(100*(JD_epsZ),'b','Linewidth',2);axis tight;grid on; title('JD');
subplot(6,6,33);
plot(100*(JC_epsZ),'b','Linewidth',2);axis tight;grid on; title('JC');
subplot(6,6,34);
plot(100*(netJC_epsZ),'b','Linewidth',2);axis tight;grid on; title('netJC');
*/

/*
subplot(6,5,1);
plot(100*(cmdata_epsZ),'b','Linewidth',2);axis tight;grid on; title('Consumption');
subplot(6,5,2);
plot(100*(u_epsZ*u_SS),'b','Linewidth',2);axis tight;grid on; title('Unemployment rate');
subplot(6,5,3);
plot(100*(ikdata_epsZ),'b','Linewidth',2);axis tight;grid on; title('Investment physical capital');
subplot(6,5,4);
plot(100*(gdpIncomedata_epsZ),'b','Linewidth',2);axis tight;grid on; title('GDP');
subplot(6,5,5);
plot(100*(wdata_epsZ),'b','Linewidth',2);grid on;axis tight, title('Wage');
subplot(6,5,6);
plot(100*(N_epsZ),'b','Linewidth',2);grid on;axis tight, title('Producers');
subplot(6,5,7);
plot(100*(iedata_epsZ),'b','Linewidth',2);axis tight;grid on; title('Investment new products');
subplot(6,5,8);
plot(100*(markup_epsZ),'b','Linewidth',2);axis tight;grid on; title('Markup');
subplot(6,5,9);
plot((ub_epsZ),'b','Linewidth',2);axis tight;grid on; title('Benefits');
subplot(6,5,10);
plot((fr_epsZ),'b','Linewidth',2);axis tight;grid on; title('PMR');
subplot(6,5,11);
plot((fc_epsZ),'b','Linewidth',2);axis tight;grid on; title('Firing costs');
subplot(6,5,12);
plot((wdata_epsZ),'b','Linewidth',2);axis tight;grid on; title('Wages');
subplot(6,5,13);
plot((s_epsZ),'b','Linewidth',2);axis tight;grid on; title('job-finding prob.');
subplot(6,5,14);
plot((thetaP_epsZ),'b','Linewidth',2);axis tight;grid on; title('labour mkt tight');
subplot(6,5,15);
plot((ooption_epsZ),'b','Linewidth',2);axis tight;grid on; title('outside option');
subplot(6,5,16);
plot((m_epsZ),'b','Linewidth',2);axis tight;grid on; title('matches');
subplot(6,5,17);
plot((q_epsZ),'b','Linewidth',2);axis tight;grid on; title('prob. fill vacancy');
subplot(6,5,18);
plot((zc_epsZ),'b','Linewidth',2);axis tight;grid on; title('prod. cut-off');
subplot(6,5,19);
plot((firing_epsZ),'b','Linewidth',2);axis tight;grid on; title('firing');
subplot(6,5,20);
plot((v_epsZ),'b','Linewidth',2);axis tight;grid on; title('vacancies');
subplot(6,5,21);
plot((vfirm_epsZ),'b','Linewidth',2);axis tight;grid on; title('firm vac');
subplot(6,5,22);
plot((lfirm_epsZ),'b','Linewidth',2);axis tight;grid on; title('firm emp');
subplot(6,5,23);
plot((endosepfirm_epsZ),'b','Linewidth',2);axis tight;grid on; title('endosep firm');
subplot(6,5,24);
plot((rho_epsZ),'b','Linewidth',2);axis tight;grid on; title('endo. separate');
subplot(6,5,25);
plot((exosepfirm_epsZ),'b','Linewidth',2);axis tight;grid on; title('exosep firm');
subplot(6,5,26);
plot((endosepAG_epsZ),'b','Linewidth',2);axis tight;grid on; title('endosep agg');
subplot(6,5,27);
plot((exosepAG_epsZ),'b','Linewidth',2);axis tight;grid on; title('exosep agg');
subplot(6,5,28);
plot((l_epsZ),'b','Linewidth',2);axis tight;grid on; title('emp');
subplot(6,5,29);
plot((newhiresfirm_epsZ),'b','Linewidth',2);axis tight;grid on; title('firm newhires');
subplot(6,5,30);
plot((newhiresAG_epsZ),'b','Linewidth',2);axis tight;grid on; title('Agg newhires');
*/


/*
subplot(3,4,1);
plot(100*(cmdata_epsZ),'b','Linewidth',2);axis tight;grid on; title('Consumption');
subplot(3,4,2);
plot(100*(u_epsZ*u_SS),'b','Linewidth',2);axis tight;grid on; title('Unemployment rate');
subplot(3,4,3);
plot(100*(ikdata_epsZ),'b','Linewidth',2);axis tight;grid on; title('Investment physical capital');
subplot(3,4,4);
plot(100*(gdpIncomedata_epsZ),'b','Linewidth',2);axis tight;grid on; title('GDP');
subplot(3,4,5);
plot(100*(wdata_epsZ),'b','Linewidth',2);grid on;axis tight, title('Wage');
subplot(3,4,6);
plot(100*(N_epsZ),'b','Linewidth',2);grid on;axis tight, title('Producers');
subplot(3,4,7);
plot(100*(iedata_epsZ),'b','Linewidth',2);axis tight;grid on; title('Investment new products');
subplot(3,4,8);
plot(100*(markup_epsZ),'b','Linewidth',2);axis tight;grid on; title('Markup');
subplot(3,4,9);
plot((ub_epsZ),'b','Linewidth',2);axis tight;grid on; title('Benefits');
*/


subplot(2,4,1);
plot(100*(cmdata_epsZ),'b','Linewidth',2);axis tight;grid on; title('Consumption');
subplot(2,4,2);
plot(100*(u_epsZ*u_SS),'b','Linewidth',2);axis tight;grid on; title('Unemployment rate');
subplot(2,4,3);
plot(100*(ikdata_epsZ),'b','Linewidth',2);axis tight;grid on; title('Investment physical capital');
subplot(2,4,4);
plot(100*(gdpIncomedata_epsZ),'b','Linewidth',2);axis tight;grid on; title('GDP');
subplot(2,4,5);
plot(100*(wdata_epsZ),'b','Linewidth',2);grid on;axis tight, title('Wage');
subplot(2,4,6);
plot(100*(N_epsZ),'b','Linewidth',2);grid on;axis tight, title('Producers');
subplot(2,4,7);
plot(100*(iedata_epsZ),'b','Linewidth',2);axis tight;grid on; title('Investment new products');
subplot(2,4,8);
plot(100*(markup_epsZ),'b','Linewidth',2);axis tight;grid on; title('Markup');

