function [residual, g1, g2, g3] = cycle_irf_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(56, 1);
T61 = params(2)*exp(y(76))/exp(y(49));
T115 = exp(y(55))*exp(y(21))^params(20);
T119 = exp(y(1))^params(10);
T120 = T115*T119;
T124 = exp(y(11))^(1-params(10));
T182 = params(2)*(1-params(13))*exp(y(76))/exp(y(49));
T208 = exp(.5*(params(14)-exp(y(37)))/(exp(y(37))*params(14)*params(15)));
T228 = 1/exp(y(39))*exp(y(30))/exp(y(37));
T248 = y(64)*exp(y(45))*exp(y(22))*exp(y(37))/(1-exp(y(22)));
T263 = 1-params(12)/2*y(34)^2;
T282 = exp(y(15))/exp(y(2));
T285 = exp(y(33))*(T263-params(12)*y(34)*T282);
T292 = exp(y(66))/exp(y(15));
T293 = T292^2;
T295 = exp(y(71))*T61*params(12)*y(72)*T293;
T334 = exp(y(76))/exp(y(49))*params(2)*(1-params(5))*(1-params(13))*exp(y(19));
T336 = exp(y(69))*(1-exp(y(67)))*T334;
T344 = exp(y(45))*exp(y(38))/exp(y(17));
T361 = params(16)*exp(y(12))^(1-params(7));
T362 = exp(y(20))^params(7);
T384 = params(11)^0.5;
T390 = params(20)*params(9)^2;
T400 = (-0.5)*T384*exp(params(20)*0.5*(2*params(8)+T390)/(1-2*params(10)+params(10)^2));
T416 = 0.7071067811865475/params(9)*(params(8)+T390+(-log(exp(y(16))))+params(10)*log(exp(y(16)))-params(10)*params(8))/((-1)+params(10));
T436 = exp(params(10)*params(8)*(-params(20))/((-1)+params(10))^2);
T438 = T400*(erf(T416)-erf(0.7071067811865475*(params(8)+T390+(-10000000000)+params(10)*10000000000-params(10)*params(8))/params(9)/((-1)+params(10))))*T436/T384;
T458 = exp(y(43))*(1-params(10))*exp(y(32))/exp(y(11));
T461 = exp(y(16))/exp(y(21));
T464 = exp(y(23))*T461^params(21);
T470 = exp(y(43))*params(10)*exp(y(32))/exp(y(1));
T489 = exp(y(10))^(-params(1));
lhs =y(47);
rhs =log(exp(y(10)))-params(26)*(1-exp(y(20)))^2/2;
residual(1)= lhs-rhs;
lhs =y(48);
rhs =y(47)+params(2)*y(75);
residual(2)= lhs-rhs;
residual(3) = (-exp(y(45)))+(1-params(5))*(1-exp(y(22)))*exp(y(7))+(1-params(5))*(1-exp(y(22)))*exp(y(3))*exp(y(6));
residual(4) = (-params(17))/exp(y(17))+(1-params(5))*(1-params(13))*T61*((1-exp(y(67)))*exp(y(68))-exp(y(67))*y(64));
residual(5) = (-exp(y(51)))+exp(y(29))-params(17)/exp(y(17))-y(64);
residual(6) = (-exp(y(26)))+(1-params(6))/params(6)*exp(y(27));
residual(7) = (-exp(y(29)))+exp(y(13))-params(6)*(exp(y(23))-exp(y(51)));
residual(8) = (-exp(y(43)))+T120*T124;
residual(9) = (-exp(y(36)))+exp(y(39))*exp(y(42))-exp(y(45))*exp(y(13))-params(17)*exp(y(44))-exp(y(24))*exp(y(46))-y(64)*exp(y(45))*exp(y(22))/(1-exp(y(22)));
residual(10) = (-exp(y(35)))+params(18)+y(65)+params(17)*(exp(y(44))+exp(y(45))/exp(y(17)));
residual(11) = (-exp(y(42)))+exp(y(43))/exp(y(37));
residual(12) = (-exp(y(39)))+exp(y(41))*exp(y(32));
residual(13) = (-exp(y(35)))+T182*(exp(y(73))+exp(y(74)));
residual(14) = (-exp(y(37)))+(1-params(13))*(exp(y(4))+exp(y(5)));
residual(15) = (-1)+exp(y(39))*T208;
residual(16) = (-exp(y(41)))+exp(y(40))/(exp(y(40))-1);
residual(17) = (-exp(y(40)))+1+exp(y(37))*params(15);
residual(18) = (-exp(y(42)))+T228;
residual(19) = (-exp(y(30)))+exp(y(53))+exp(y(15))+params(17)*exp(y(12))+(params(18)+y(65))*exp(y(38))+T248;
residual(20) = (-exp(y(14)))+exp(y(1))*(1-params(19))+exp(y(15))*T263;
residual(21) = (-exp(y(33)))+T61*(exp(y(70))+(1-params(19))*exp(y(71)));
residual(22) = (-1)+T285+T295;
residual(23) = T282-y(34)-1;
residual(24) = (1-params(5))*(1-params(13))*T61*((1-exp(y(67)))*exp(y(68))-exp(y(67))*y(77))+exp(y(23))-exp(y(25))-exp(y(13));
residual(25) = (1-params(5))*(1-params(13))*T61*(1-exp(y(67)))*exp(y(69))+exp(y(13))-exp(y(27))-exp(y(28));
residual(26) = (-exp(y(28)))+params(23)+exp(y(63))+T336;
residual(27) = (-exp(y(12)))+exp(y(44))*(exp(y(37))+exp(y(38)))+T344;
residual(28) = (-exp(y(45)))+exp(y(11))/exp(y(37));
residual(29) = (-exp(y(46)))+exp(y(1))/exp(y(37));
residual(30) = (-exp(y(18)))+T361*T362;
residual(31) = 1-exp(y(20))-exp(y(11));
residual(32) = (-exp(y(19)))+exp(y(18))/exp(y(20));
residual(33) = (-exp(y(17)))+exp(y(18))/exp(y(12));
residual(34) = (-exp(y(50)))+T438/(1-exp(y(22)));
residual(35) = (-exp(y(21)))+exp(y(50))^((1-params(10))/params(20));
residual(36) = (-exp(y(22)))+0.5+0.5*erf(log(exp(y(16)))/(params(9)*1.414213562373095));
residual(37) = (-exp(y(23)))+T458;
residual(38) = (-exp(y(51)))+T464;
residual(39) = (-exp(y(24)))+T470;
residual(40) = y(64)+(-exp(y(26)))+exp(y(25));
residual(41) = exp(y(24))-exp(y(31));
residual(42) = exp(y(10))-exp(y(53))-params(23)*(1-exp(y(11)));
lhs =y(49);
rhs =log(T489);
residual(43)= lhs-rhs;
residual(44) = (-y(55))+params(3)*y(8)-x(it_, 1);
residual(45) = (-exp(y(63)))+params(71)+params(25)*(y(57)-y(9));
residual(46) = (-y(64))+params(72);
residual(47) = (-y(65))+params(73);
residual(48) = (1-exp(y(22)))*(1-params(5))*params(13)+(1-params(5))*exp(y(22))+params(5)-exp(y(52));
residual(49) = (-exp(y(56)))+exp(y(13))*exp(y(11))+exp(y(1))*exp(y(31))+exp(y(36))*exp(y(37));
residual(50) = (params(18)+y(65))*exp(y(38))-exp(y(54));
residual(51) = (-exp(y(57)))+exp(y(56))/exp(y(39));
residual(52) = (-exp(y(58)))+exp(y(53))/exp(y(39));
residual(53) = (-exp(y(59)))+exp(y(15))/exp(y(39));
residual(54) = (-exp(y(61)))+exp(y(13))/exp(y(39));
residual(55) = (-exp(y(62)))+exp(y(10))/exp(y(39));
residual(56) = (-exp(y(60)))+exp(y(54))/exp(y(39));
if nargout >= 2,
  g1 = zeros(56, 78);

  %
  % Jacobian matrix
  %

T637 = (-(exp(y(15))*exp(y(2))))/(exp(y(2))*exp(y(2)));
T674 = getPowerDeriv(T461,params(21),1);
T821 = (-(params(2)*exp(y(76))*exp(y(49))))/(exp(y(49))*exp(y(49)));
T826 = (-(exp(y(76))*exp(y(49))))/(exp(y(49))*exp(y(49)));
  g1(1,10)=(-1);
  g1(1,20)=params(26)*(-exp(y(20)))*2*(1-exp(y(20)))/2;
  g1(1,47)=1;
  g1(2,47)=(-1);
  g1(2,48)=1;
  g1(2,75)=(-params(2));
  g1(3,3)=(1-params(5))*(1-exp(y(22)))*exp(y(3))*exp(y(6));
  g1(3,22)=exp(y(7))*(1-params(5))*(-exp(y(22)))+exp(y(6))*exp(y(3))*(1-params(5))*(-exp(y(22)));
  g1(3,6)=(1-params(5))*(1-exp(y(22)))*exp(y(3))*exp(y(6));
  g1(3,7)=(1-params(5))*(1-exp(y(22)))*exp(y(7));
  g1(3,45)=(-exp(y(45)));
  g1(4,17)=(-((-params(17))*exp(y(17))))/(exp(y(17))*exp(y(17)));
  g1(4,67)=(1-params(5))*(1-params(13))*T61*(exp(y(68))*(-exp(y(67)))-exp(y(67))*y(64));
  g1(4,68)=(1-params(5))*(1-params(13))*T61*(1-exp(y(67)))*exp(y(68));
  g1(4,49)=((1-exp(y(67)))*exp(y(68))-exp(y(67))*y(64))*(1-params(5))*(1-params(13))*T821;
  g1(4,76)=(1-params(5))*(1-params(13))*T61*((1-exp(y(67)))*exp(y(68))-exp(y(67))*y(64));
  g1(4,64)=(1-params(5))*(1-params(13))*T61*(-exp(y(67)));
  g1(5,17)=(-((-(params(17)*exp(y(17))))/(exp(y(17))*exp(y(17)))));
  g1(5,29)=exp(y(29));
  g1(5,51)=(-exp(y(51)));
  g1(5,64)=(-1);
  g1(6,26)=(-exp(y(26)));
  g1(6,27)=(1-params(6))/params(6)*exp(y(27));
  g1(7,13)=exp(y(13));
  g1(7,23)=(-(params(6)*exp(y(23))));
  g1(7,29)=(-exp(y(29)));
  g1(7,51)=(-((-exp(y(51)))*params(6)));
  g1(8,11)=T120*exp(y(11))*getPowerDeriv(exp(y(11)),1-params(10),1);
  g1(8,1)=T124*T115*exp(y(1))*getPowerDeriv(exp(y(1)),params(10),1);
  g1(8,21)=T124*T119*exp(y(55))*exp(y(21))*getPowerDeriv(exp(y(21)),params(20),1);
  g1(8,43)=(-exp(y(43)));
  g1(8,55)=T120*T124;
  g1(9,13)=(-(exp(y(45))*exp(y(13))));
  g1(9,22)=(-(((1-exp(y(22)))*y(64)*exp(y(45))*exp(y(22))-y(64)*exp(y(45))*exp(y(22))*(-exp(y(22))))/((1-exp(y(22)))*(1-exp(y(22))))));
  g1(9,24)=(-(exp(y(24))*exp(y(46))));
  g1(9,36)=(-exp(y(36)));
  g1(9,39)=exp(y(39))*exp(y(42));
  g1(9,42)=exp(y(39))*exp(y(42));
  g1(9,44)=(-(params(17)*exp(y(44))));
  g1(9,45)=(-(exp(y(45))*exp(y(13))))-y(64)*exp(y(45))*exp(y(22))/(1-exp(y(22)));
  g1(9,46)=(-(exp(y(24))*exp(y(46))));
  g1(9,64)=(-(exp(y(45))*exp(y(22))/(1-exp(y(22)))));
  g1(10,17)=params(17)*(-(exp(y(45))*exp(y(17))))/(exp(y(17))*exp(y(17)));
  g1(10,35)=(-exp(y(35)));
  g1(10,44)=params(17)*exp(y(44));
  g1(10,45)=params(17)*exp(y(45))/exp(y(17));
  g1(10,65)=1;
  g1(11,37)=(-(exp(y(43))*exp(y(37))))/(exp(y(37))*exp(y(37)));
  g1(11,42)=(-exp(y(42)));
  g1(11,43)=exp(y(43))/exp(y(37));
  g1(12,32)=exp(y(41))*exp(y(32));
  g1(12,39)=(-exp(y(39)));
  g1(12,41)=exp(y(41))*exp(y(32));
  g1(13,35)=(-exp(y(35)));
  g1(13,73)=T182*exp(y(73));
  g1(13,74)=T182*exp(y(74));
  g1(13,49)=(exp(y(73))+exp(y(74)))*params(2)*(1-params(13))*T826;
  g1(13,76)=T182*(exp(y(73))+exp(y(74)));
  g1(14,4)=(1-params(13))*exp(y(4));
  g1(14,37)=(-exp(y(37)));
  g1(14,5)=(1-params(13))*exp(y(5));
  g1(15,37)=exp(y(39))*T208*(exp(y(37))*params(14)*params(15)*(-exp(y(37)))*.5-.5*(params(14)-exp(y(37)))*exp(y(37))*params(14)*params(15))/(exp(y(37))*params(14)*params(15)*exp(y(37))*params(14)*params(15));
  g1(15,39)=exp(y(39))*T208;
  g1(16,40)=(exp(y(40))*(exp(y(40))-1)-exp(y(40))*exp(y(40)))/((exp(y(40))-1)*(exp(y(40))-1));
  g1(16,41)=(-exp(y(41)));
  g1(17,37)=exp(y(37))*params(15);
  g1(17,40)=(-exp(y(40)));
  g1(18,30)=T228;
  g1(18,37)=(-(exp(y(37))*1/exp(y(39))*exp(y(30))))/(exp(y(37))*exp(y(37)));
  g1(18,39)=exp(y(30))*(-exp(y(39)))/(exp(y(39))*exp(y(39)))/exp(y(37));
  g1(18,42)=(-exp(y(42)));
  g1(19,12)=params(17)*exp(y(12));
  g1(19,15)=exp(y(15));
  g1(19,22)=((1-exp(y(22)))*y(64)*exp(y(45))*exp(y(22))*exp(y(37))-y(64)*exp(y(45))*exp(y(22))*exp(y(37))*(-exp(y(22))))/((1-exp(y(22)))*(1-exp(y(22))));
  g1(19,30)=(-exp(y(30)));
  g1(19,37)=T248;
  g1(19,38)=(params(18)+y(65))*exp(y(38));
  g1(19,45)=T248;
  g1(19,53)=exp(y(53));
  g1(19,64)=exp(y(45))*exp(y(22))*exp(y(37))/(1-exp(y(22)));
  g1(19,65)=exp(y(38));
  g1(20,1)=exp(y(1))*(1-params(19));
  g1(20,14)=(-exp(y(14)));
  g1(20,15)=exp(y(15))*T263;
  g1(20,34)=exp(y(15))*(-(params(12)/2*2*y(34)));
  g1(21,70)=T61*exp(y(70));
  g1(21,33)=(-exp(y(33)));
  g1(21,71)=T61*(1-params(19))*exp(y(71));
  g1(21,49)=(exp(y(70))+(1-params(19))*exp(y(71)))*T821;
  g1(21,76)=T61*(exp(y(70))+(1-params(19))*exp(y(71)));
  g1(22,2)=exp(y(33))*(-(params(12)*y(34)*T637));
  g1(22,15)=exp(y(33))*(-(params(12)*y(34)*T282))+exp(y(71))*T61*params(12)*y(72)*(-(exp(y(15))*exp(y(66))))/(exp(y(15))*exp(y(15)))*2*T292;
  g1(22,66)=exp(y(71))*T61*params(12)*y(72)*T292*2*T292;
  g1(22,33)=T285;
  g1(22,71)=T295;
  g1(22,34)=exp(y(33))*((-(params(12)/2*2*y(34)))-params(12)*T282);
  g1(22,72)=exp(y(71))*T61*params(12)*T293;
  g1(22,49)=y(72)*T293*exp(y(71))*params(12)*T821;
  g1(22,76)=T295;
  g1(23,2)=T637;
  g1(23,15)=T282;
  g1(23,34)=(-1);
  g1(24,13)=(-exp(y(13)));
  g1(24,67)=(1-params(5))*(1-params(13))*T61*(exp(y(68))*(-exp(y(67)))-exp(y(67))*y(77));
  g1(24,23)=exp(y(23));
  g1(24,25)=(-exp(y(25)));
  g1(24,68)=(1-params(5))*(1-params(13))*T61*(1-exp(y(67)))*exp(y(68));
  g1(24,49)=((1-exp(y(67)))*exp(y(68))-exp(y(67))*y(77))*(1-params(5))*(1-params(13))*T821;
  g1(24,76)=(1-params(5))*(1-params(13))*T61*((1-exp(y(67)))*exp(y(68))-exp(y(67))*y(77));
  g1(24,77)=(1-params(5))*(1-params(13))*T61*(-exp(y(67)));
  g1(25,13)=exp(y(13));
  g1(25,67)=exp(y(69))*(1-params(5))*(1-params(13))*T61*(-exp(y(67)));
  g1(25,27)=(-exp(y(27)));
  g1(25,69)=(1-params(5))*(1-params(13))*T61*(1-exp(y(67)))*exp(y(69));
  g1(25,28)=(-exp(y(28)));
  g1(25,49)=exp(y(69))*(1-exp(y(67)))*(1-params(5))*(1-params(13))*T821;
  g1(25,76)=(1-params(5))*(1-params(13))*T61*(1-exp(y(67)))*exp(y(69));
  g1(26,19)=T336;
  g1(26,67)=exp(y(69))*T334*(-exp(y(67)));
  g1(26,69)=T336;
  g1(26,28)=(-exp(y(28)));
  g1(26,49)=exp(y(69))*(1-exp(y(67)))*exp(y(19))*params(2)*(1-params(5))*(1-params(13))*T826;
  g1(26,76)=T336;
  g1(26,63)=exp(y(63));
  g1(27,12)=(-exp(y(12)));
  g1(27,17)=(-(exp(y(17))*exp(y(45))*exp(y(38))))/(exp(y(17))*exp(y(17)));
  g1(27,37)=exp(y(44))*exp(y(37));
  g1(27,38)=T344+exp(y(44))*exp(y(38));
  g1(27,44)=exp(y(44))*(exp(y(37))+exp(y(38)));
  g1(27,45)=T344;
  g1(28,11)=exp(y(11))/exp(y(37));
  g1(28,37)=(-(exp(y(11))*exp(y(37))))/(exp(y(37))*exp(y(37)));
  g1(28,45)=(-exp(y(45)));
  g1(29,1)=exp(y(1))/exp(y(37));
  g1(29,37)=(-(exp(y(1))*exp(y(37))))/(exp(y(37))*exp(y(37)));
  g1(29,46)=(-exp(y(46)));
  g1(30,12)=T362*params(16)*exp(y(12))*getPowerDeriv(exp(y(12)),1-params(7),1);
  g1(30,18)=(-exp(y(18)));
  g1(30,20)=T361*exp(y(20))*getPowerDeriv(exp(y(20)),params(7),1);
  g1(31,11)=(-exp(y(11)));
  g1(31,20)=(-exp(y(20)));
  g1(32,18)=exp(y(18))/exp(y(20));
  g1(32,19)=(-exp(y(19)));
  g1(32,20)=(-(exp(y(20))*exp(y(18))))/(exp(y(20))*exp(y(20)));
  g1(33,12)=(-(exp(y(12))*exp(y(18))))/(exp(y(12))*exp(y(12)));
  g1(33,17)=(-exp(y(17)));
  g1(33,18)=exp(y(18))/exp(y(12));
  g1(34,16)=T436*T400*0.7071067811865475/params(9)*((-1)+params(10))/((-1)+params(10))*2/(exp(T416^2)*1.772453850905516)/T384/(1-exp(y(22)));
  g1(34,22)=(-(T438*(-exp(y(22)))))/((1-exp(y(22)))*(1-exp(y(22))));
  g1(34,50)=(-exp(y(50)));
  g1(35,21)=(-exp(y(21)));
  g1(35,50)=exp(y(50))*getPowerDeriv(exp(y(50)),(1-params(10))/params(20),1);
  g1(36,16)=0.5*1/(params(9)*1.414213562373095)*2/(1.772453850905516*exp((log(exp(y(16)))/(params(9)*1.414213562373095))^2));
  g1(36,22)=(-exp(y(22)));
  g1(37,11)=(-(exp(y(11))*exp(y(43))*(1-params(10))*exp(y(32))))/(exp(y(11))*exp(y(11)));
  g1(37,23)=(-exp(y(23)));
  g1(37,32)=T458;
  g1(37,43)=T458;
  g1(38,16)=exp(y(23))*T461*T674;
  g1(38,21)=exp(y(23))*T674*(-(exp(y(21))*exp(y(16))))/(exp(y(21))*exp(y(21)));
  g1(38,23)=T464;
  g1(38,51)=(-exp(y(51)));
  g1(39,1)=(-(exp(y(1))*exp(y(43))*params(10)*exp(y(32))))/(exp(y(1))*exp(y(1)));
  g1(39,24)=(-exp(y(24)));
  g1(39,32)=T470;
  g1(39,43)=T470;
  g1(40,25)=exp(y(25));
  g1(40,26)=(-exp(y(26)));
  g1(40,64)=1;
  g1(41,24)=exp(y(24));
  g1(41,31)=(-exp(y(31)));
  g1(42,10)=exp(y(10));
  g1(42,11)=(-(params(23)*(-exp(y(11)))));
  g1(42,53)=(-exp(y(53)));
  g1(43,10)=(-(exp(y(10))*getPowerDeriv(exp(y(10)),(-params(1)),1)/T489));
  g1(43,49)=1;
  g1(44,8)=params(3);
  g1(44,55)=(-1);
  g1(44,78)=(-1);
  g1(45,9)=(-params(25));
  g1(45,57)=params(25);
  g1(45,63)=(-exp(y(63)));
  g1(46,64)=(-1);
  g1(47,65)=(-1);
  g1(48,22)=(1-params(5))*exp(y(22))+(-exp(y(22)))*(1-params(5))*params(13);
  g1(48,52)=(-exp(y(52)));
  g1(49,11)=exp(y(13))*exp(y(11));
  g1(49,13)=exp(y(13))*exp(y(11));
  g1(49,1)=exp(y(1))*exp(y(31));
  g1(49,31)=exp(y(1))*exp(y(31));
  g1(49,36)=exp(y(36))*exp(y(37));
  g1(49,37)=exp(y(36))*exp(y(37));
  g1(49,56)=(-exp(y(56)));
  g1(50,38)=(params(18)+y(65))*exp(y(38));
  g1(50,54)=(-exp(y(54)));
  g1(50,65)=exp(y(38));
  g1(51,39)=(-(exp(y(39))*exp(y(56))))/(exp(y(39))*exp(y(39)));
  g1(51,56)=exp(y(56))/exp(y(39));
  g1(51,57)=(-exp(y(57)));
  g1(52,39)=(-(exp(y(39))*exp(y(53))))/(exp(y(39))*exp(y(39)));
  g1(52,53)=exp(y(53))/exp(y(39));
  g1(52,58)=(-exp(y(58)));
  g1(53,15)=exp(y(15))/exp(y(39));
  g1(53,39)=(-(exp(y(39))*exp(y(15))))/(exp(y(39))*exp(y(39)));
  g1(53,59)=(-exp(y(59)));
  g1(54,13)=exp(y(13))/exp(y(39));
  g1(54,39)=(-(exp(y(13))*exp(y(39))))/(exp(y(39))*exp(y(39)));
  g1(54,61)=(-exp(y(61)));
  g1(55,10)=exp(y(10))/exp(y(39));
  g1(55,39)=(-(exp(y(10))*exp(y(39))))/(exp(y(39))*exp(y(39)));
  g1(55,62)=(-exp(y(62)));
  g1(56,39)=(-(exp(y(39))*exp(y(54))))/(exp(y(39))*exp(y(39)));
  g1(56,54)=exp(y(54))/exp(y(39));
  g1(56,60)=(-exp(y(60)));

if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],56,6084);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],56,474552);
end
end
end
end
