function [residual, g1, g2, g3] = cycle_moments_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(56, 1);
T34 = 1-exp(y(22));
T45 = (1-params(5))*T34*exp(y(3))*exp(y(6));
T61 = params(2)*exp(y(76))/exp(y(49));
T72 = (1-params(5))*(1-params(13))*T61*((1-exp(y(67)))*exp(y(68))-exp(y(67))*y(64));
T93 = (1-params(6))/params(6)*exp(y(27));
T115 = exp(y(55))*exp(y(21))^params(20);
T119 = exp(y(1))^params(10);
T120 = T115*T119;
T124 = exp(y(11))^(1-params(10));
T169 = exp(y(43))/exp(y(37));
T182 = params(2)*(1-params(13))*exp(y(76))/exp(y(49));
T208 = exp(.5*(params(14)-exp(y(37)))/(exp(y(37))*params(14)*params(15)));
T228 = 1/exp(y(39))*exp(y(30))/exp(y(37));
T248 = y(64)*exp(y(45))*exp(y(22))*exp(y(37))/T34;
T263 = 1-params(12)/2*y(34)^2;
T282 = exp(y(15))/exp(y(2));
T285 = exp(y(33))*(T263-params(12)*y(34)*T282);
T292 = exp(y(66))/exp(y(15));
T293 = T292^2;
T295 = exp(y(71))*T61*params(12)*y(72)*T293;
T310 = (1-params(5))*(1-params(13))*T61*((1-exp(y(67)))*exp(y(68))-exp(y(67))*y(77));
T321 = (1-params(5))*(1-params(13))*T61*(1-exp(y(67)))*exp(y(69));
T334 = exp(y(76))/exp(y(49))*params(2)*(1-params(5))*(1-params(13))*exp(y(19));
T336 = exp(y(69))*(1-exp(y(67)))*T334;
T344 = exp(y(45))*exp(y(38))/exp(y(17));
T347 = exp(y(11))/exp(y(37));
T351 = exp(y(1))/exp(y(37));
T361 = params(16)*exp(y(12))^(1-params(7));
T362 = exp(y(20))^params(7);
T371 = exp(y(18))/exp(y(20));
T375 = exp(y(18))/exp(y(12));
T384 = params(11)^0.5;
T390 = params(20)*params(9)^2;
T400 = (-0.5)*T384*exp(params(20)*0.5*(2*params(8)+T390)/(1-2*params(10)+params(10)^2));
T416 = 0.7071067811865475/params(9)*(params(8)+T390+(-log(exp(y(16))))+params(10)*log(exp(y(16)))-params(10)*params(8))/((-1)+params(10));
T436 = exp(params(10)*params(8)*(-params(20))/((-1)+params(10))^2);
T438 = T400*(erf(T416)-erf(0.7071067811865475*(params(8)+T390+(-10000000000)+params(10)*10000000000-params(10)*params(8))/params(9)/((-1)+params(10))))*T436/T384;
T449 = log(exp(y(16)))/(params(9)*1.414213562373095);
T458 = exp(y(43))*(1-params(10))*exp(y(32))/exp(y(11));
T461 = exp(y(16))/exp(y(21));
T464 = exp(y(23))*T461^params(21);
T470 = exp(y(43))*params(10)*exp(y(32))/exp(y(1));
T546 = exp(y(56))/exp(y(39));
T552 = exp(y(53))/exp(y(39));
T558 = exp(y(15))/exp(y(39));
T564 = exp(y(13))/exp(y(39));
T570 = exp(y(10))/exp(y(39));
T576 = exp(y(54))/exp(y(39));
lhs =y(47);
rhs =log(exp(y(10)))-params(25)*(1-exp(y(20)))^2/2;
residual(1)= lhs-rhs;
lhs =y(48);
rhs =y(47)+params(2)*y(75);
residual(2)= lhs-rhs;
residual(3) = (-exp(y(45)))+(1-params(5))*T34*exp(y(7))+T45;
residual(4) = (-params(17))/exp(y(17))+T72;
residual(5) = (-exp(y(51)))+exp(y(29))-params(17)/exp(y(17))-y(64);
residual(6) = (-exp(y(26)))+T93;
residual(7) = (-exp(y(29)))+exp(y(13))-params(6)*(exp(y(23))-exp(y(51)));
residual(8) = (-exp(y(43)))+T120*T124;
residual(9) = (-exp(y(36)))+exp(y(39))*exp(y(42))-exp(y(45))*exp(y(13))-params(17)*exp(y(44))-exp(y(24))*exp(y(46))-y(64)*exp(y(45))*exp(y(22))/T34;
residual(10) = (-exp(y(35)))+params(18)+y(65)+params(17)*(exp(y(44))+exp(y(45))/exp(y(17)));
residual(11) = (-exp(y(42)))+T169;
residual(12) = (-exp(y(39)))+exp(y(41))*exp(y(32));
residual(13) = (-exp(y(35)))+T182*(exp(y(73))+exp(y(74)));
residual(14) = (-exp(y(37)))+(1-params(13))*(exp(y(4))+exp(y(5)));
residual(15) = (-1)+exp(y(39))*T208;
residual(16) = (-exp(y(41)))+exp(y(40))/(exp(y(40))-1);
residual(17) = (-exp(y(40)))+1+exp(y(37))*params(15);
residual(18) = (-exp(y(42)))+T228;
residual(19) = (-exp(y(30)))+exp(y(53))+exp(y(15))+params(17)*exp(y(12))+(params(18)+y(65))*exp(y(38))+T248;
residual(20) = (-exp(y(14)))+exp(y(1))*(1-params(19))+exp(y(15))*T263;
residual(21) = (-exp(y(33)))+T61*(exp(y(70))+(1-params(19))*exp(y(71)));
residual(22) = (-1)+T285+T295;
residual(23) = T282-y(34)-1;
residual(24) = T310+exp(y(23))-exp(y(25))-exp(y(13));
residual(25) = T321+exp(y(13))-exp(y(27))-exp(y(28));
residual(26) = (-exp(y(28)))+params(23)+exp(y(63))+T336;
residual(27) = (-exp(y(12)))+exp(y(44))*(exp(y(37))+exp(y(38)))+T344;
residual(28) = (-exp(y(45)))+T347;
residual(29) = (-exp(y(46)))+T351;
residual(30) = (-exp(y(18)))+T361*T362;
residual(31) = 1-exp(y(20))-exp(y(11));
residual(32) = (-exp(y(19)))+T371;
residual(33) = (-exp(y(17)))+T375;
residual(34) = (-exp(y(50)))+T438/T34;
residual(35) = (-exp(y(21)))+exp(y(50))^((1-params(10))/params(20));
residual(36) = (-exp(y(22)))+0.5+0.5*erf(T449);
residual(37) = (-exp(y(23)))+T458;
residual(38) = (-exp(y(51)))+T464;
residual(39) = (-exp(y(24)))+T470;
residual(40) = y(64)+(-exp(y(26)))+exp(y(25));
residual(41) = exp(y(24))-exp(y(31));
residual(42) = exp(y(10))-exp(y(53))-params(23)*(1-exp(y(11)));
residual(43) = (-exp(y(49)))+exp(y(10))^(-params(1));
residual(44) = (-y(55))+params(3)*y(8)-x(it_, 1);
residual(45) = (-exp(y(63)))+params(70)+params(24)*(y(57)-y(9));
residual(46) = (-y(64))+params(71);
residual(47) = (-y(65))+params(72);
residual(48) = T34*(1-params(5))*params(13)+(1-params(5))*exp(y(22))+params(5)-exp(y(52));
residual(49) = (-exp(y(56)))+exp(y(13))*exp(y(11))+exp(y(1))*exp(y(31))+exp(y(36))*exp(y(37));
residual(50) = (params(18)+y(65))*exp(y(38))-exp(y(54));
residual(51) = (-exp(y(57)))+T546;
residual(52) = (-exp(y(58)))+T552;
residual(53) = (-exp(y(59)))+T558;
residual(54) = (-exp(y(61)))+T564;
residual(55) = (-exp(y(62)))+T570;
residual(56) = (-exp(y(60)))+T576;
if nargout >= 2,
  g1 = zeros(56, 78);

  %
  % Jacobian matrix
  %

T604 = exp(y(10))*getPowerDeriv(exp(y(10)),(-params(1)),1);
T606 = exp(y(11))*getPowerDeriv(exp(y(11)),1-params(10),1);
T612 = (-(exp(y(11))*exp(y(43))*(1-params(10))*exp(y(32))))/(exp(y(11))*exp(y(11)));
T616 = exp(y(12))*getPowerDeriv(exp(y(12)),1-params(7),1);
T622 = (-(exp(y(12))*exp(y(18))))/(exp(y(12))*exp(y(12)));
T626 = exp(y(1))*getPowerDeriv(exp(y(1)),params(10),1);
T627 = T115*T626;
T632 = (-(exp(y(1))*exp(y(43))*params(10)*exp(y(32))))/(exp(y(1))*exp(y(1)));
T636 = (-(exp(y(15))*exp(y(2))))/(exp(y(2))*exp(y(2)));
T645 = (-(exp(y(15))*exp(y(66))))/(exp(y(15))*exp(y(15)));
T655 = 0.7071067811865475/params(9)*((-1)+params(10))/((-1)+params(10));
T657 = exp(T416^2);
T664 = T436*T400*T655*2/(T657*1.772453850905516)/T384;
T668 = exp(T449^2);
T673 = getPowerDeriv(T461,params(21),1);
T678 = exp(y(17))*exp(y(17));
T690 = (-(exp(y(17))*exp(y(45))*exp(y(38))))/T678;
T697 = exp(y(20))*getPowerDeriv(exp(y(20)),params(7),1);
T702 = (-(exp(y(20))*exp(y(18))))/(exp(y(20))*exp(y(20)));
T704 = exp(y(21))*getPowerDeriv(exp(y(21)),params(20),1);
T705 = exp(y(55))*T704;
T706 = T119*T705;
T711 = (-(exp(y(21))*exp(y(16))))/(exp(y(21))*exp(y(21)));
T712 = T673*T711;
T722 = T34*T34;
T724 = (-((T34*y(64)*exp(y(45))*exp(y(22))-y(64)*exp(y(45))*exp(y(22))*(-exp(y(22))))/T722));
T726 = y(64)*exp(y(45))*exp(y(22))*exp(y(37))*(-exp(y(22)));
T728 = (T34*y(64)*exp(y(45))*exp(y(22))*exp(y(37))-T726)/T722;
T737 = (1-params(5))*(1-params(13))*T61*(exp(y(68))*(-exp(y(67)))-exp(y(67))*y(64));
T739 = (1-params(5))*(1-params(13))*T61*(exp(y(68))*(-exp(y(67)))-exp(y(67))*y(77));
T740 = (1-params(5))*(1-params(13))*T61*(-exp(y(67)));
T747 = (1-params(5))*(1-params(13))*T61*(1-exp(y(67)))*exp(y(68));
T763 = exp(y(37))*exp(y(37));
T769 = exp(y(37))*params(14)*params(15)*exp(y(37))*params(14)*params(15);
T770 = (exp(y(37))*params(14)*params(15)*(-exp(y(37)))*.5-.5*(params(14)-exp(y(37)))*exp(y(37))*params(14)*params(15))/T769;
T774 = (-(exp(y(37))*1/exp(y(39))*exp(y(30))));
T775 = T774/T763;
T786 = exp(y(39))*exp(y(39));
T788 = exp(y(30))*(-exp(y(39)))/T786;
T789 = T788/exp(y(37));
T814 = (-(exp(y(45))*exp(y(13))))-y(64)*exp(y(45))*exp(y(22))/T34;
T820 = (-(params(2)*exp(y(76))*exp(y(49))))/(exp(y(49))*exp(y(49)));
T825 = (-(exp(y(76))*exp(y(49))))/(exp(y(49))*exp(y(49)));
T838 = exp(y(69))*(1-exp(y(67)))*exp(y(19))*params(2)*(1-params(5))*(1-params(13))*T825;
T840 = exp(y(50))*getPowerDeriv(exp(y(50)),(1-params(10))/params(20),1);
T846 = exp(y(45))*exp(y(22))*exp(y(37))/T34;
  g1(1,10)=(-1);
  g1(1,20)=params(25)*(-exp(y(20)))*2*(1-exp(y(20)))/2;
  g1(1,47)=1;
  g1(2,47)=(-1);
  g1(2,48)=1;
  g1(2,75)=(-params(2));
  g1(3,3)=T45;
  g1(3,22)=exp(y(7))*(1-params(5))*(-exp(y(22)))+exp(y(6))*exp(y(3))*(1-params(5))*(-exp(y(22)));
  g1(3,6)=T45;
  g1(3,7)=(1-params(5))*T34*exp(y(7));
  g1(3,45)=(-exp(y(45)));
  g1(4,17)=(-((-params(17))*exp(y(17))))/T678;
  g1(4,67)=T737;
  g1(4,68)=T747;
  g1(4,49)=((1-exp(y(67)))*exp(y(68))-exp(y(67))*y(64))*(1-params(5))*(1-params(13))*T820;
  g1(4,76)=T72;
  g1(4,64)=T740;
  g1(5,17)=(-((-(params(17)*exp(y(17))))/T678));
  g1(5,29)=exp(y(29));
  g1(5,51)=(-exp(y(51)));
  g1(5,64)=(-1);
  g1(6,26)=(-exp(y(26)));
  g1(6,27)=T93;
  g1(7,13)=exp(y(13));
  g1(7,23)=(-(params(6)*exp(y(23))));
  g1(7,29)=(-exp(y(29)));
  g1(7,51)=(-((-exp(y(51)))*params(6)));
  g1(8,11)=T120*T606;
  g1(8,1)=T124*T627;
  g1(8,21)=T124*T706;
  g1(8,43)=(-exp(y(43)));
  g1(8,55)=T120*T124;
  g1(9,13)=(-(exp(y(45))*exp(y(13))));
  g1(9,22)=T724;
  g1(9,24)=(-(exp(y(24))*exp(y(46))));
  g1(9,36)=(-exp(y(36)));
  g1(9,39)=exp(y(39))*exp(y(42));
  g1(9,42)=exp(y(39))*exp(y(42));
  g1(9,44)=(-(params(17)*exp(y(44))));
  g1(9,45)=T814;
  g1(9,46)=(-(exp(y(24))*exp(y(46))));
  g1(9,64)=(-(exp(y(45))*exp(y(22))/T34));
  g1(10,17)=params(17)*(-(exp(y(45))*exp(y(17))))/T678;
  g1(10,35)=(-exp(y(35)));
  g1(10,44)=params(17)*exp(y(44));
  g1(10,45)=params(17)*exp(y(45))/exp(y(17));
  g1(10,65)=1;
  g1(11,37)=(-(exp(y(43))*exp(y(37))))/T763;
  g1(11,42)=(-exp(y(42)));
  g1(11,43)=T169;
  g1(12,32)=exp(y(41))*exp(y(32));
  g1(12,39)=(-exp(y(39)));
  g1(12,41)=exp(y(41))*exp(y(32));
  g1(13,35)=(-exp(y(35)));
  g1(13,73)=T182*exp(y(73));
  g1(13,74)=T182*exp(y(74));
  g1(13,49)=(exp(y(73))+exp(y(74)))*params(2)*(1-params(13))*T825;
  g1(13,76)=T182*(exp(y(73))+exp(y(74)));
  g1(14,4)=(1-params(13))*exp(y(4));
  g1(14,37)=(-exp(y(37)));
  g1(14,5)=(1-params(13))*exp(y(5));
  g1(15,37)=exp(y(39))*T208*T770;
  g1(15,39)=exp(y(39))*T208;
  g1(16,40)=(exp(y(40))*(exp(y(40))-1)-exp(y(40))*exp(y(40)))/((exp(y(40))-1)*(exp(y(40))-1));
  g1(16,41)=(-exp(y(41)));
  g1(17,37)=exp(y(37))*params(15);
  g1(17,40)=(-exp(y(40)));
  g1(18,30)=T228;
  g1(18,37)=T775;
  g1(18,39)=T789;
  g1(18,42)=(-exp(y(42)));
  g1(19,12)=params(17)*exp(y(12));
  g1(19,15)=exp(y(15));
  g1(19,22)=T728;
  g1(19,30)=(-exp(y(30)));
  g1(19,37)=T248;
  g1(19,38)=(params(18)+y(65))*exp(y(38));
  g1(19,45)=T248;
  g1(19,53)=exp(y(53));
  g1(19,64)=T846;
  g1(19,65)=exp(y(38));
  g1(20,1)=exp(y(1))*(1-params(19));
  g1(20,14)=(-exp(y(14)));
  g1(20,15)=exp(y(15))*T263;
  g1(20,34)=exp(y(15))*(-(params(12)/2*2*y(34)));
  g1(21,70)=T61*exp(y(70));
  g1(21,33)=(-exp(y(33)));
  g1(21,71)=T61*(1-params(19))*exp(y(71));
  g1(21,49)=(exp(y(70))+(1-params(19))*exp(y(71)))*T820;
  g1(21,76)=T61*(exp(y(70))+(1-params(19))*exp(y(71)));
  g1(22,2)=exp(y(33))*(-(params(12)*y(34)*T636));
  g1(22,15)=exp(y(33))*(-(params(12)*y(34)*T282))+exp(y(71))*T61*params(12)*y(72)*T645*2*T292;
  g1(22,66)=exp(y(71))*T61*params(12)*y(72)*T292*2*T292;
  g1(22,33)=T285;
  g1(22,71)=T295;
  g1(22,34)=exp(y(33))*((-(params(12)/2*2*y(34)))-params(12)*T282);
  g1(22,72)=exp(y(71))*T61*params(12)*T293;
  g1(22,49)=y(72)*T293*exp(y(71))*params(12)*T820;
  g1(22,76)=T295;
  g1(23,2)=T636;
  g1(23,15)=T282;
  g1(23,34)=(-1);
  g1(24,13)=(-exp(y(13)));
  g1(24,67)=T739;
  g1(24,23)=exp(y(23));
  g1(24,25)=(-exp(y(25)));
  g1(24,68)=T747;
  g1(24,49)=((1-exp(y(67)))*exp(y(68))-exp(y(67))*y(77))*(1-params(5))*(1-params(13))*T820;
  g1(24,76)=T310;
  g1(24,77)=T740;
  g1(25,13)=exp(y(13));
  g1(25,67)=exp(y(69))*T740;
  g1(25,27)=(-exp(y(27)));
  g1(25,69)=T321;
  g1(25,28)=(-exp(y(28)));
  g1(25,49)=exp(y(69))*(1-exp(y(67)))*(1-params(5))*(1-params(13))*T820;
  g1(25,76)=T321;
  g1(26,19)=T336;
  g1(26,67)=exp(y(69))*T334*(-exp(y(67)));
  g1(26,69)=T336;
  g1(26,28)=(-exp(y(28)));
  g1(26,49)=T838;
  g1(26,76)=T336;
  g1(26,63)=exp(y(63));
  g1(27,12)=(-exp(y(12)));
  g1(27,17)=T690;
  g1(27,37)=exp(y(44))*exp(y(37));
  g1(27,38)=T344+exp(y(44))*exp(y(38));
  g1(27,44)=exp(y(44))*(exp(y(37))+exp(y(38)));
  g1(27,45)=T344;
  g1(28,11)=T347;
  g1(28,37)=(-(exp(y(11))*exp(y(37))))/T763;
  g1(28,45)=(-exp(y(45)));
  g1(29,1)=T351;
  g1(29,37)=(-(exp(y(1))*exp(y(37))))/T763;
  g1(29,46)=(-exp(y(46)));
  g1(30,12)=T362*params(16)*T616;
  g1(30,18)=(-exp(y(18)));
  g1(30,20)=T361*T697;
  g1(31,11)=(-exp(y(11)));
  g1(31,20)=(-exp(y(20)));
  g1(32,18)=T371;
  g1(32,19)=(-exp(y(19)));
  g1(32,20)=T702;
  g1(33,12)=T622;
  g1(33,17)=(-exp(y(17)));
  g1(33,18)=T375;
  g1(34,16)=T664/T34;
  g1(34,22)=(-(T438*(-exp(y(22)))))/T722;
  g1(34,50)=(-exp(y(50)));
  g1(35,21)=(-exp(y(21)));
  g1(35,50)=T840;
  g1(36,16)=0.5*1/(params(9)*1.414213562373095)*2/(1.772453850905516*T668);
  g1(36,22)=(-exp(y(22)));
  g1(37,11)=T612;
  g1(37,23)=(-exp(y(23)));
  g1(37,32)=T458;
  g1(37,43)=T458;
  g1(38,16)=exp(y(23))*T461*T673;
  g1(38,21)=exp(y(23))*T712;
  g1(38,23)=T464;
  g1(38,51)=(-exp(y(51)));
  g1(39,1)=T632;
  g1(39,24)=(-exp(y(24)));
  g1(39,32)=T470;
  g1(39,43)=T470;
  g1(40,25)=exp(y(25));
  g1(40,26)=(-exp(y(26)));
  g1(40,64)=1;
  g1(41,24)=exp(y(24));
  g1(41,31)=(-exp(y(31)));
  g1(42,10)=exp(y(10));
  g1(42,11)=(-(params(23)*(-exp(y(11)))));
  g1(42,53)=(-exp(y(53)));
  g1(43,10)=T604;
  g1(43,49)=(-exp(y(49)));
  g1(44,8)=params(3);
  g1(44,55)=(-1);
  g1(44,78)=(-1);
  g1(45,9)=(-params(24));
  g1(45,57)=params(24);
  g1(45,63)=(-exp(y(63)));
  g1(46,64)=(-1);
  g1(47,65)=(-1);
  g1(48,22)=(1-params(5))*exp(y(22))+(-exp(y(22)))*(1-params(5))*params(13);
  g1(48,52)=(-exp(y(52)));
  g1(49,11)=exp(y(13))*exp(y(11));
  g1(49,13)=exp(y(13))*exp(y(11));
  g1(49,1)=exp(y(1))*exp(y(31));
  g1(49,31)=exp(y(1))*exp(y(31));
  g1(49,36)=exp(y(36))*exp(y(37));
  g1(49,37)=exp(y(36))*exp(y(37));
  g1(49,56)=(-exp(y(56)));
  g1(50,38)=(params(18)+y(65))*exp(y(38));
  g1(50,54)=(-exp(y(54)));
  g1(50,65)=exp(y(38));
  g1(51,39)=(-(exp(y(39))*exp(y(56))))/T786;
  g1(51,56)=T546;
  g1(51,57)=(-exp(y(57)));
  g1(52,39)=(-(exp(y(39))*exp(y(53))))/T786;
  g1(52,53)=T552;
  g1(52,58)=(-exp(y(58)));
  g1(53,15)=T558;
  g1(53,39)=(-(exp(y(39))*exp(y(15))))/T786;
  g1(53,59)=(-exp(y(59)));
  g1(54,13)=T564;
  g1(54,39)=(-(exp(y(13))*exp(y(39))))/T786;
  g1(54,61)=(-exp(y(61)));
  g1(55,10)=T570;
  g1(55,39)=(-(exp(y(10))*exp(y(39))))/T786;
  g1(55,62)=(-exp(y(62)));
  g1(56,39)=(-(exp(y(39))*exp(y(54))))/T786;
  g1(56,54)=T576;
  g1(56,60)=(-exp(y(60)));

if nargout >= 3,
  %
  % Hessian matrix
  %

  v2 = zeros(445,3);
T866 = ((-(params(2)*exp(y(76))*exp(y(49))))*exp(y(49))*exp(y(49))-(-(params(2)*exp(y(76))*exp(y(49))))*(exp(y(49))*exp(y(49))+exp(y(49))*exp(y(49))))/(exp(y(49))*exp(y(49))*exp(y(49))*exp(y(49)));
T929 = (exp(y(49))*exp(y(49))*(-(exp(y(76))*exp(y(49))))-(-(exp(y(76))*exp(y(49))))*(exp(y(49))*exp(y(49))+exp(y(49))*exp(y(49))))/(exp(y(49))*exp(y(49))*exp(y(49))*exp(y(49)));
T991 = ((-(exp(y(15))*exp(y(2))))*exp(y(2))*exp(y(2))-(-(exp(y(15))*exp(y(2))))*(exp(y(2))*exp(y(2))+exp(y(2))*exp(y(2))))/(exp(y(2))*exp(y(2))*exp(y(2))*exp(y(2)));
T1116 = getPowerDeriv(T461,params(21),2);
T1117 = T461*T1116;
  v2(1,1)=1;
  v2(1,2)=1502;
  v2(1,3)=params(25)*((-exp(y(20)))*2*(1-exp(y(20)))+(-exp(y(20)))*2*(-exp(y(20))))/2;
  v2(2,1)=3;
  v2(2,2)=159;
  v2(2,3)=T45;
  v2(3,1)=3;
  v2(3,2)=1641;
  v2(3,3)=exp(y(6))*exp(y(3))*(1-params(5))*(-exp(y(22)));
  v2(4,1)=3;
  v2(4,2)=178;
  v2(4,3)=  v2(3,3);
  v2(5,1)=3;
  v2(5,2)=1660;
  v2(5,3)=exp(y(7))*(1-params(5))*(-exp(y(22)))+exp(y(6))*exp(y(3))*(1-params(5))*(-exp(y(22)));
  v2(6,1)=3;
  v2(6,2)=393;
  v2(6,3)=T45;
  v2(7,1)=3;
  v2(7,2)=162;
  v2(7,3)=  v2(6,3);
  v2(8,1)=3;
  v2(8,2)=412;
  v2(8,3)=exp(y(6))*exp(y(3))*(1-params(5))*(-exp(y(22)));
  v2(9,1)=3;
  v2(9,2)=1644;
  v2(9,3)=  v2(8,3);
  v2(10,1)=3;
  v2(10,2)=396;
  v2(10,3)=T45;
  v2(11,1)=3;
  v2(11,2)=490;
  v2(11,3)=exp(y(7))*(1-params(5))*(-exp(y(22)));
  v2(12,1)=3;
  v2(12,2)=1645;
  v2(12,3)=  v2(11,3);
  v2(13,1)=3;
  v2(13,2)=475;
  v2(13,3)=(1-params(5))*T34*exp(y(7));
  v2(14,1)=3;
  v2(14,2)=3477;
  v2(14,3)=(-exp(y(45)));
  v2(15,1)=4;
  v2(15,2)=1265;
  v2(15,3)=((-((-params(17))*exp(y(17))))*T678-(-((-params(17))*exp(y(17))))*(T678+T678))/(T678*T678);
  v2(16,1)=4;
  v2(16,2)=5215;
  v2(16,3)=T737;
  v2(17,1)=4;
  v2(17,2)=5293;
  v2(17,3)=(1-params(5))*(1-params(13))*T61*exp(y(68))*(-exp(y(67)));
  v2(18,1)=4;
  v2(18,2)=5216;
  v2(18,3)=  v2(17,3);
  v2(19,1)=4;
  v2(19,2)=5294;
  v2(19,3)=T747;
  v2(20,1)=4;
  v2(20,2)=3811;
  v2(20,3)=(exp(y(68))*(-exp(y(67)))-exp(y(67))*y(64))*(1-params(5))*(1-params(13))*T820;
  v2(21,1)=4;
  v2(21,2)=5197;
  v2(21,3)=  v2(20,3);
  v2(22,1)=4;
  v2(22,2)=3812;
  v2(22,3)=(1-exp(y(67)))*exp(y(68))*(1-params(5))*(1-params(13))*T820;
  v2(23,1)=4;
  v2(23,2)=5275;
  v2(23,3)=  v2(22,3);
  v2(24,1)=4;
  v2(24,2)=3793;
  v2(24,3)=((1-exp(y(67)))*exp(y(68))-exp(y(67))*y(64))*(1-params(5))*(1-params(13))*T866;
  v2(25,1)=4;
  v2(25,2)=5917;
  v2(25,3)=T737;
  v2(26,1)=4;
  v2(26,2)=5224;
  v2(26,3)=  v2(25,3);
  v2(27,1)=4;
  v2(27,2)=5918;
  v2(27,3)=T747;
  v2(28,1)=4;
  v2(28,2)=5302;
  v2(28,3)=  v2(27,3);
  v2(29,1)=4;
  v2(29,2)=5899;
  v2(29,3)=((1-exp(y(67)))*exp(y(68))-exp(y(67))*y(64))*(1-params(5))*(1-params(13))*T820;
  v2(30,1)=4;
  v2(30,2)=3820;
  v2(30,3)=  v2(29,3);
  v2(31,1)=4;
  v2(31,2)=5926;
  v2(31,3)=T72;
  v2(32,1)=4;
  v2(32,2)=4981;
  v2(32,3)=T740;
  v2(33,1)=4;
  v2(33,2)=5212;
  v2(33,3)=  v2(32,3);
  v2(34,1)=4;
  v2(34,2)=4963;
  v2(34,3)=(-exp(y(67)))*(1-params(5))*(1-params(13))*T820;
  v2(35,1)=4;
  v2(35,2)=3808;
  v2(35,3)=  v2(34,3);
  v2(36,1)=4;
  v2(36,2)=4990;
  v2(36,3)=T740;
  v2(37,1)=4;
  v2(37,2)=5914;
  v2(37,3)=  v2(36,3);
  v2(38,1)=5;
  v2(38,2)=1265;
  v2(38,3)=(-((T678*(-(params(17)*exp(y(17))))-(-(params(17)*exp(y(17))))*(T678+T678))/(T678*T678)));
  v2(39,1)=5;
  v2(39,2)=2213;
  v2(39,3)=exp(y(29));
  v2(40,1)=5;
  v2(40,2)=3951;
  v2(40,3)=(-exp(y(51)));
  v2(41,1)=6;
  v2(41,2)=1976;
  v2(41,3)=(-exp(y(26)));
  v2(42,1)=6;
  v2(42,2)=2055;
  v2(42,3)=T93;
  v2(43,1)=7;
  v2(43,2)=949;
  v2(43,3)=exp(y(13));
  v2(44,1)=7;
  v2(44,2)=1739;
  v2(44,3)=(-(params(6)*exp(y(23))));
  v2(45,1)=7;
  v2(45,2)=2213;
  v2(45,3)=(-exp(y(29)));
  v2(46,1)=7;
  v2(46,2)=3951;
  v2(46,3)=(-((-exp(y(51)))*params(6)));
  v2(47,1)=8;
  v2(47,2)=791;
  v2(47,3)=T120*(T606+exp(y(11))*exp(y(11))*getPowerDeriv(exp(y(11)),1-params(10),2));
  v2(48,1)=8;
  v2(48,2)=11;
  v2(48,3)=T606*T627;
  v2(49,1)=8;
  v2(49,2)=781;
  v2(49,3)=  v2(48,3);
  v2(50,1)=8;
  v2(50,2)=1;
  v2(50,3)=T124*T115*(T626+exp(y(1))*exp(y(1))*getPowerDeriv(exp(y(1)),params(10),2));
  v2(51,1)=8;
  v2(51,2)=1571;
  v2(51,3)=T606*T706;
  v2(52,1)=8;
  v2(52,2)=801;
  v2(52,3)=  v2(51,3);
  v2(53,1)=8;
  v2(53,2)=1561;
  v2(53,3)=T124*T626*T705;
  v2(54,1)=8;
  v2(54,2)=21;
  v2(54,3)=  v2(53,3);
  v2(55,1)=8;
  v2(55,2)=1581;
  v2(55,3)=T124*T119*exp(y(55))*(T704+exp(y(21))*exp(y(21))*getPowerDeriv(exp(y(21)),params(20),2));
  v2(56,1)=8;
  v2(56,2)=3319;
  v2(56,3)=(-exp(y(43)));
  v2(57,1)=8;
  v2(57,2)=4223;
  v2(57,3)=T120*T606;
  v2(58,1)=8;
  v2(58,2)=835;
  v2(58,3)=  v2(57,3);
  v2(59,1)=8;
  v2(59,2)=4213;
  v2(59,3)=T124*T627;
  v2(60,1)=8;
  v2(60,2)=55;
  v2(60,3)=  v2(59,3);
  v2(61,1)=8;
  v2(61,2)=4233;
  v2(61,3)=T124*T706;
  v2(62,1)=8;
  v2(62,2)=1615;
  v2(62,3)=  v2(61,3);
  v2(63,1)=8;
  v2(63,2)=4267;
  v2(63,3)=T120*T124;
  v2(64,1)=9;
  v2(64,2)=949;
  v2(64,3)=(-(exp(y(45))*exp(y(13))));
  v2(65,1)=9;
  v2(65,2)=1660;
  v2(65,3)=(-((T722*(T34*y(64)*exp(y(45))*exp(y(22))+y(64)*exp(y(45))*exp(y(22))*(-exp(y(22)))-(y(64)*exp(y(45))*exp(y(22))*(-exp(y(22)))+y(64)*exp(y(45))*exp(y(22))*(-exp(y(22)))))-(T34*y(64)*exp(y(45))*exp(y(22))-y(64)*exp(y(45))*exp(y(22))*(-exp(y(22))))*(T34*(-exp(y(22)))+T34*(-exp(y(22)))))/(T722*T722)));
  v2(66,1)=9;
  v2(66,2)=1818;
  v2(66,3)=(-(exp(y(24))*exp(y(46))));
  v2(67,1)=9;
  v2(67,2)=2766;
  v2(67,3)=(-exp(y(36)));
  v2(68,1)=9;
  v2(68,2)=3003;
  v2(68,3)=exp(y(39))*exp(y(42));
  v2(69,1)=9;
  v2(69,2)=3237;
  v2(69,3)=exp(y(39))*exp(y(42));
  v2(70,1)=9;
  v2(70,2)=3006;
  v2(70,3)=  v2(69,3);
  v2(71,1)=9;
  v2(71,2)=3240;
  v2(71,3)=exp(y(39))*exp(y(42));
  v2(72,1)=9;
  v2(72,2)=3398;
  v2(72,3)=(-(params(17)*exp(y(44))));
  v2(73,1)=9;
  v2(73,2)=3445;
  v2(73,3)=(-(exp(y(45))*exp(y(13))));
  v2(74,1)=9;
  v2(74,2)=981;
  v2(74,3)=  v2(73,3);
  v2(75,1)=9;
  v2(75,2)=3454;
  v2(75,3)=T724;
  v2(76,1)=9;
  v2(76,2)=1683;
  v2(76,3)=  v2(75,3);
  v2(77,1)=9;
  v2(77,2)=3477;
  v2(77,3)=T814;
  v2(78,1)=9;
  v2(78,2)=3534;
  v2(78,3)=(-(exp(y(24))*exp(y(46))));
  v2(79,1)=9;
  v2(79,2)=1840;
  v2(79,3)=  v2(78,3);
  v2(80,1)=9;
  v2(80,2)=3556;
  v2(80,3)=(-(exp(y(24))*exp(y(46))));
  v2(81,1)=9;
  v2(81,2)=4936;
  v2(81,3)=(-((T34*exp(y(45))*exp(y(22))-exp(y(45))*exp(y(22))*(-exp(y(22))))/T722));
  v2(82,1)=9;
  v2(82,2)=1702;
  v2(82,3)=  v2(81,3);
  v2(83,1)=9;
  v2(83,2)=4959;
  v2(83,3)=(-(exp(y(45))*exp(y(22))/T34));
  v2(84,1)=9;
  v2(84,2)=3496;
  v2(84,3)=  v2(83,3);
  v2(85,1)=10;
  v2(85,2)=1265;
  v2(85,3)=params(17)*(T678*(-(exp(y(45))*exp(y(17))))-(-(exp(y(45))*exp(y(17))))*(T678+T678))/(T678*T678);
  v2(86,1)=10;
  v2(86,2)=2687;
  v2(86,3)=(-exp(y(35)));
  v2(87,1)=10;
  v2(87,2)=3398;
  v2(87,3)=params(17)*exp(y(44));
  v2(88,1)=10;
  v2(88,2)=3449;
  v2(88,3)=params(17)*(-(exp(y(45))*exp(y(17))))/T678;
  v2(89,1)=10;
  v2(89,2)=1293;
  v2(89,3)=  v2(88,3);
  v2(90,1)=10;
  v2(90,2)=3477;
  v2(90,3)=params(17)*exp(y(45))/exp(y(17));
  v2(91,1)=11;
  v2(91,2)=2845;
  v2(91,3)=((-(exp(y(43))*exp(y(37))))*T763-(-(exp(y(43))*exp(y(37))))*(T763+T763))/(T763*T763);
  v2(92,1)=11;
  v2(92,2)=3240;
  v2(92,3)=(-exp(y(42)));
  v2(93,1)=11;
  v2(93,2)=3313;
  v2(93,3)=(-(exp(y(43))*exp(y(37))))/T763;
  v2(94,1)=11;
  v2(94,2)=2851;
  v2(94,3)=  v2(93,3);
  v2(95,1)=11;
  v2(95,2)=3319;
  v2(95,3)=T169;
  v2(96,1)=12;
  v2(96,2)=2450;
  v2(96,3)=exp(y(41))*exp(y(32));
  v2(97,1)=12;
  v2(97,2)=3003;
  v2(97,3)=(-exp(y(39)));
  v2(98,1)=12;
  v2(98,2)=3152;
  v2(98,3)=exp(y(41))*exp(y(32));
  v2(99,1)=12;
  v2(99,2)=2459;
  v2(99,3)=  v2(98,3);
  v2(100,1)=12;
  v2(100,2)=3161;
  v2(100,3)=exp(y(41))*exp(y(32));
  v2(101,1)=13;
  v2(101,2)=2687;
  v2(101,3)=(-exp(y(35)));
  v2(102,1)=13;
  v2(102,2)=5689;
  v2(102,3)=T182*exp(y(73));
  v2(103,1)=13;
  v2(103,2)=5768;
  v2(103,3)=T182*exp(y(74));
  v2(104,1)=13;
  v2(104,2)=3817;
  v2(104,3)=exp(y(73))*params(2)*(1-params(13))*T825;
  v2(105,1)=13;
  v2(105,2)=5665;
  v2(105,3)=  v2(104,3);
  v2(106,1)=13;
  v2(106,2)=3818;
  v2(106,3)=exp(y(74))*params(2)*(1-params(13))*T825;
  v2(107,1)=13;
  v2(107,2)=5743;
  v2(107,3)=  v2(106,3);
  v2(108,1)=13;
  v2(108,2)=3793;
  v2(108,3)=(exp(y(73))+exp(y(74)))*params(2)*(1-params(13))*T929;
  v2(109,1)=13;
  v2(109,2)=5923;
  v2(109,3)=T182*exp(y(73));
  v2(110,1)=13;
  v2(110,2)=5692;
  v2(110,3)=  v2(109,3);
  v2(111,1)=13;
  v2(111,2)=5924;
  v2(111,3)=T182*exp(y(74));
  v2(112,1)=13;
  v2(112,2)=5770;
  v2(112,3)=  v2(111,3);
  v2(113,1)=13;
  v2(113,2)=5899;
  v2(113,3)=(exp(y(73))+exp(y(74)))*params(2)*(1-params(13))*T825;
  v2(114,1)=13;
  v2(114,2)=3820;
  v2(114,3)=  v2(113,3);
  v2(115,1)=13;
  v2(115,2)=5926;
  v2(115,3)=T182*(exp(y(73))+exp(y(74)));
  v2(116,1)=14;
  v2(116,2)=238;
  v2(116,3)=(1-params(13))*exp(y(4));
  v2(117,1)=14;
  v2(117,2)=2845;
  v2(117,3)=(-exp(y(37)));
  v2(118,1)=14;
  v2(118,2)=317;
  v2(118,3)=(1-params(13))*exp(y(5));
  v2(119,1)=15;
  v2(119,2)=2845;
  v2(119,3)=exp(y(39))*(T770*T208*T770+T208*(T769*(exp(y(37))*params(14)*params(15)*(-exp(y(37)))*.5+exp(y(37))*params(14)*params(15)*(-exp(y(37)))*.5-(exp(y(37))*params(14)*params(15)*(-exp(y(37)))*.5+.5*(params(14)-exp(y(37)))*exp(y(37))*params(14)*params(15)))-(exp(y(37))*params(14)*params(15)*(-exp(y(37)))*.5-.5*(params(14)-exp(y(37)))*exp(y(37))*params(14)*params(15))*(T769+T769))/(T769*T769));
  v2(120,1)=15;
  v2(120,2)=3001;
  v2(120,3)=exp(y(39))*T208*T770;
  v2(121,1)=15;
  v2(121,2)=2847;
  v2(121,3)=  v2(120,3);
  v2(122,1)=15;
  v2(122,2)=3003;
  v2(122,3)=exp(y(39))*T208;
  v2(123,1)=16;
  v2(123,2)=3082;
  v2(123,3)=((exp(y(40))-1)*(exp(y(40))-1)*(exp(y(40))*(exp(y(40))-1)+exp(y(40))*exp(y(40))-(exp(y(40))*exp(y(40))+exp(y(40))*exp(y(40))))-(exp(y(40))*(exp(y(40))-1)-exp(y(40))*exp(y(40)))*(exp(y(40))*(exp(y(40))-1)+exp(y(40))*(exp(y(40))-1)))/((exp(y(40))-1)*(exp(y(40))-1)*(exp(y(40))-1)*(exp(y(40))-1));
  v2(124,1)=16;
  v2(124,2)=3161;
  v2(124,3)=(-exp(y(41)));
  v2(125,1)=17;
  v2(125,2)=2845;
  v2(125,3)=exp(y(37))*params(15);
  v2(126,1)=17;
  v2(126,2)=3082;
  v2(126,3)=(-exp(y(40)));
  v2(127,1)=18;
  v2(127,2)=2292;
  v2(127,3)=T228;
  v2(128,1)=18;
  v2(128,2)=2838;
  v2(128,3)=T775;
  v2(129,1)=18;
  v2(129,2)=2299;
  v2(129,3)=  v2(128,3);
  v2(130,1)=18;
  v2(130,2)=2845;
  v2(130,3)=(T763*T774-T774*(T763+T763))/(T763*T763);
  v2(131,1)=18;
  v2(131,2)=2994;
  v2(131,3)=T789;
  v2(132,1)=18;
  v2(132,2)=2301;
  v2(132,3)=  v2(131,3);
  v2(133,1)=18;
  v2(133,2)=3001;
  v2(133,3)=(-(exp(y(37))*T788))/T763;
  v2(134,1)=18;
  v2(134,2)=2847;
  v2(134,3)=  v2(133,3);
  v2(135,1)=18;
  v2(135,2)=3003;
  v2(135,3)=exp(y(30))*((-exp(y(39)))*T786-(-exp(y(39)))*(T786+T786))/(T786*T786)/exp(y(37));
  v2(136,1)=18;
  v2(136,2)=3240;
  v2(136,3)=(-exp(y(42)));
  v2(137,1)=19;
  v2(137,2)=870;
  v2(137,3)=params(17)*exp(y(12));
  v2(138,1)=19;
  v2(138,2)=1107;
  v2(138,3)=exp(y(15));
  v2(139,1)=19;
  v2(139,2)=1660;
  v2(139,3)=(T722*(T34*y(64)*exp(y(45))*exp(y(22))*exp(y(37))+T726-(T726+T726))-(T34*y(64)*exp(y(45))*exp(y(22))*exp(y(37))-T726)*(T34*(-exp(y(22)))+T34*(-exp(y(22)))))/(T722*T722);
  v2(140,1)=19;
  v2(140,2)=2292;
  v2(140,3)=(-exp(y(30)));
  v2(141,1)=19;
  v2(141,2)=2830;
  v2(141,3)=T728;
  v2(142,1)=19;
  v2(142,2)=1675;
  v2(142,3)=  v2(141,3);
  v2(143,1)=19;
  v2(143,2)=2845;
  v2(143,3)=T248;
  v2(144,1)=19;
  v2(144,2)=2924;
  v2(144,3)=(params(18)+y(65))*exp(y(38));
  v2(145,1)=19;
  v2(145,2)=3454;
  v2(145,3)=T728;
  v2(146,1)=19;
  v2(146,2)=1683;
  v2(146,3)=  v2(145,3);
  v2(147,1)=19;
  v2(147,2)=3469;
  v2(147,3)=T248;
  v2(148,1)=19;
  v2(148,2)=2853;
  v2(148,3)=  v2(147,3);
  v2(149,1)=19;
  v2(149,2)=3477;
  v2(149,3)=T248;
  v2(150,1)=19;
  v2(150,2)=4109;
  v2(150,3)=exp(y(53));
  v2(151,1)=19;
  v2(151,2)=4936;
  v2(151,3)=(T34*exp(y(45))*exp(y(22))*exp(y(37))-exp(y(45))*exp(y(22))*exp(y(37))*(-exp(y(22))))/T722;
  v2(152,1)=19;
  v2(152,2)=1702;
  v2(152,3)=  v2(151,3);
  v2(153,1)=19;
  v2(153,2)=4951;
  v2(153,3)=T846;
  v2(154,1)=19;
  v2(154,2)=2872;
  v2(154,3)=  v2(153,3);
  v2(155,1)=19;
  v2(155,2)=4959;
  v2(155,3)=T846;
  v2(156,1)=19;
  v2(156,2)=3496;
  v2(156,3)=  v2(155,3);
  v2(157,1)=19;
  v2(157,2)=5030;
  v2(157,3)=exp(y(38));
  v2(158,1)=19;
  v2(158,2)=2951;
  v2(158,3)=  v2(157,3);
  v2(159,1)=20;
  v2(159,2)=1;
  v2(159,3)=exp(y(1))*(1-params(19));
  v2(160,1)=20;
  v2(160,2)=1028;
  v2(160,3)=(-exp(y(14)));
  v2(161,1)=20;
  v2(161,2)=1107;
  v2(161,3)=exp(y(15))*T263;
  v2(162,1)=20;
  v2(162,2)=2589;
  v2(162,3)=exp(y(15))*(-(params(12)/2*2*y(34)));
  v2(163,1)=20;
  v2(163,2)=1126;
  v2(163,3)=  v2(162,3);
  v2(164,1)=20;
  v2(164,2)=2608;
  v2(164,3)=exp(y(15))*(-(2*params(12)/2));
  v2(165,1)=21;
  v2(165,2)=5452;
  v2(165,3)=T61*exp(y(70));
  v2(166,1)=21;
  v2(166,2)=2529;
  v2(166,3)=(-exp(y(33)));
  v2(167,1)=21;
  v2(167,2)=5531;
  v2(167,3)=T61*(1-params(19))*exp(y(71));
  v2(168,1)=21;
  v2(168,2)=3814;
  v2(168,3)=exp(y(70))*T820;
  v2(169,1)=21;
  v2(169,2)=5431;
  v2(169,3)=  v2(168,3);
  v2(170,1)=21;
  v2(170,2)=3815;
  v2(170,3)=(1-params(19))*exp(y(71))*T820;
  v2(171,1)=21;
  v2(171,2)=5509;
  v2(171,3)=  v2(170,3);
  v2(172,1)=21;
  v2(172,2)=3793;
  v2(172,3)=(exp(y(70))+(1-params(19))*exp(y(71)))*T866;
  v2(173,1)=21;
  v2(173,2)=5920;
  v2(173,3)=T61*exp(y(70));
  v2(174,1)=21;
  v2(174,2)=5458;
  v2(174,3)=  v2(173,3);
  v2(175,1)=21;
  v2(175,2)=5921;
  v2(175,3)=T61*(1-params(19))*exp(y(71));
  v2(176,1)=21;
  v2(176,2)=5536;
  v2(176,3)=  v2(175,3);
  v2(177,1)=21;
  v2(177,2)=5899;
  v2(177,3)=(exp(y(70))+(1-params(19))*exp(y(71)))*T820;
  v2(178,1)=21;
  v2(178,2)=3820;
  v2(178,3)=  v2(177,3);
  v2(179,1)=21;
  v2(179,2)=5926;
  v2(179,3)=T61*(exp(y(70))+(1-params(19))*exp(y(71)));
  v2(180,1)=22;
  v2(180,2)=80;
  v2(180,3)=exp(y(33))*(-(params(12)*y(34)*T991));
  v2(181,1)=22;
  v2(181,2)=1094;
  v2(181,3)=exp(y(33))*(-(params(12)*y(34)*T636));
  v2(182,1)=22;
  v2(182,2)=93;
  v2(182,3)=  v2(181,3);
  v2(183,1)=22;
  v2(183,2)=1107;
  v2(183,3)=exp(y(33))*(-(params(12)*y(34)*T282))+exp(y(71))*T61*params(12)*y(72)*(2*T292*((-(exp(y(15))*exp(y(66))))*exp(y(15))*exp(y(15))-(-(exp(y(15))*exp(y(66))))*(exp(y(15))*exp(y(15))+exp(y(15))*exp(y(15))))/(exp(y(15))*exp(y(15))*exp(y(15))*exp(y(15)))+T645*2*T645);
  v2(184,1)=22;
  v2(184,2)=5085;
  v2(184,3)=exp(y(71))*T61*params(12)*y(72)*(T645*2*T292+T292*2*T645);
  v2(185,1)=22;
  v2(185,2)=1158;
  v2(185,3)=  v2(184,3);
  v2(186,1)=22;
  v2(186,2)=5136;
  v2(186,3)=exp(y(71))*T61*params(12)*y(72)*(T292*2*T292+T292*2*T292);
  v2(187,1)=22;
  v2(187,2)=2498;
  v2(187,3)=exp(y(33))*(-(params(12)*y(34)*T636));
  v2(188,1)=22;
  v2(188,2)=111;
  v2(188,3)=  v2(187,3);
  v2(189,1)=22;
  v2(189,2)=2511;
  v2(189,3)=exp(y(33))*(-(params(12)*y(34)*T282));
  v2(190,1)=22;
  v2(190,2)=1125;
  v2(190,3)=  v2(189,3);
  v2(191,1)=22;
  v2(191,2)=2529;
  v2(191,3)=T285;
  v2(192,1)=22;
  v2(192,2)=5475;
  v2(192,3)=exp(y(71))*T61*params(12)*y(72)*T645*2*T292;
  v2(193,1)=22;
  v2(193,2)=1163;
  v2(193,3)=  v2(192,3);
  v2(194,1)=22;
  v2(194,2)=5526;
  v2(194,3)=exp(y(71))*T61*params(12)*y(72)*T292*2*T292;
  v2(195,1)=22;
  v2(195,2)=5141;
  v2(195,3)=  v2(194,3);
  v2(196,1)=22;
  v2(196,2)=5531;
  v2(196,3)=T295;
  v2(197,1)=22;
  v2(197,2)=2576;
  v2(197,3)=exp(y(33))*(-(params(12)*T636));
  v2(198,1)=22;
  v2(198,2)=112;
  v2(198,3)=  v2(197,3);
  v2(199,1)=22;
  v2(199,2)=2589;
  v2(199,3)=exp(y(33))*(-(params(12)*T282));
  v2(200,1)=22;
  v2(200,2)=1126;
  v2(200,3)=  v2(199,3);
  v2(201,1)=22;
  v2(201,2)=2607;
  v2(201,3)=exp(y(33))*((-(params(12)/2*2*y(34)))-params(12)*T282);
  v2(202,1)=22;
  v2(202,2)=2530;
  v2(202,3)=  v2(201,3);
  v2(203,1)=22;
  v2(203,2)=2608;
  v2(203,3)=exp(y(33))*(-(2*params(12)/2));
  v2(204,1)=22;
  v2(204,2)=5553;
  v2(204,3)=exp(y(71))*T61*params(12)*T645*2*T292;
  v2(205,1)=22;
  v2(205,2)=1164;
  v2(205,3)=  v2(204,3);
  v2(206,1)=22;
  v2(206,2)=5604;
  v2(206,3)=exp(y(71))*T61*params(12)*T292*2*T292;
  v2(207,1)=22;
  v2(207,2)=5142;
  v2(207,3)=  v2(206,3);
  v2(208,1)=22;
  v2(208,2)=5609;
  v2(208,3)=exp(y(71))*T61*params(12)*T293;
  v2(209,1)=22;
  v2(209,2)=5532;
  v2(209,3)=  v2(208,3);
  v2(210,1)=22;
  v2(210,2)=3759;
  v2(210,3)=y(72)*T645*2*T292*exp(y(71))*params(12)*T820;
  v2(211,1)=22;
  v2(211,2)=1141;
  v2(211,3)=  v2(210,3);
  v2(212,1)=22;
  v2(212,2)=3810;
  v2(212,3)=y(72)*T292*2*T292*exp(y(71))*params(12)*T820;
  v2(213,1)=22;
  v2(213,2)=5119;
  v2(213,3)=  v2(212,3);
  v2(214,1)=22;
  v2(214,2)=3815;
  v2(214,3)=y(72)*T293*exp(y(71))*params(12)*T820;
  v2(215,1)=22;
  v2(215,2)=5509;
  v2(215,3)=  v2(214,3);
  v2(216,1)=22;
  v2(216,2)=3816;
  v2(216,3)=T293*exp(y(71))*params(12)*T820;
  v2(217,1)=22;
  v2(217,2)=5587;
  v2(217,3)=  v2(216,3);
  v2(218,1)=22;
  v2(218,2)=3793;
  v2(218,3)=y(72)*T293*exp(y(71))*params(12)*T866;
  v2(219,1)=22;
  v2(219,2)=5865;
  v2(219,3)=exp(y(71))*T61*params(12)*y(72)*T645*2*T292;
  v2(220,1)=22;
  v2(220,2)=1168;
  v2(220,3)=  v2(219,3);
  v2(221,1)=22;
  v2(221,2)=5916;
  v2(221,3)=exp(y(71))*T61*params(12)*y(72)*T292*2*T292;
  v2(222,1)=22;
  v2(222,2)=5146;
  v2(222,3)=  v2(221,3);
  v2(223,1)=22;
  v2(223,2)=5921;
  v2(223,3)=T295;
  v2(224,1)=22;
  v2(224,2)=5536;
  v2(224,3)=  v2(223,3);
  v2(225,1)=22;
  v2(225,2)=5922;
  v2(225,3)=exp(y(71))*T61*params(12)*T293;
  v2(226,1)=22;
  v2(226,2)=5614;
  v2(226,3)=  v2(225,3);
  v2(227,1)=22;
  v2(227,2)=5899;
  v2(227,3)=y(72)*T293*exp(y(71))*params(12)*T820;
  v2(228,1)=22;
  v2(228,2)=3820;
  v2(228,3)=  v2(227,3);
  v2(229,1)=22;
  v2(229,2)=5926;
  v2(229,3)=T295;
  v2(230,1)=23;
  v2(230,2)=80;
  v2(230,3)=T991;
  v2(231,1)=23;
  v2(231,2)=1094;
  v2(231,3)=T636;
  v2(232,1)=23;
  v2(232,2)=93;
  v2(232,3)=  v2(231,3);
  v2(233,1)=23;
  v2(233,2)=1107;
  v2(233,3)=T282;
  v2(234,1)=24;
  v2(234,2)=949;
  v2(234,3)=(-exp(y(13)));
  v2(235,1)=24;
  v2(235,2)=5215;
  v2(235,3)=T739;
  v2(236,1)=24;
  v2(236,2)=1739;
  v2(236,3)=exp(y(23));
  v2(237,1)=24;
  v2(237,2)=1897;
  v2(237,3)=(-exp(y(25)));
  v2(238,1)=24;
  v2(238,2)=5293;
  v2(238,3)=(1-params(5))*(1-params(13))*T61*exp(y(68))*(-exp(y(67)));
  v2(239,1)=24;
  v2(239,2)=5216;
  v2(239,3)=  v2(238,3);
  v2(240,1)=24;
  v2(240,2)=5294;
  v2(240,3)=T747;
  v2(241,1)=24;
  v2(241,2)=3811;
  v2(241,3)=(exp(y(68))*(-exp(y(67)))-exp(y(67))*y(77))*(1-params(5))*(1-params(13))*T820;
  v2(242,1)=24;
  v2(242,2)=5197;
  v2(242,3)=  v2(241,3);
  v2(243,1)=24;
  v2(243,2)=3812;
  v2(243,3)=(1-exp(y(67)))*exp(y(68))*(1-params(5))*(1-params(13))*T820;
  v2(244,1)=24;
  v2(244,2)=5275;
  v2(244,3)=  v2(243,3);
  v2(245,1)=24;
  v2(245,2)=3793;
  v2(245,3)=((1-exp(y(67)))*exp(y(68))-exp(y(67))*y(77))*(1-params(5))*(1-params(13))*T866;
  v2(246,1)=24;
  v2(246,2)=5917;
  v2(246,3)=T739;
  v2(247,1)=24;
  v2(247,2)=5224;
  v2(247,3)=  v2(246,3);
  v2(248,1)=24;
  v2(248,2)=5918;
  v2(248,3)=T747;
  v2(249,1)=24;
  v2(249,2)=5302;
  v2(249,3)=  v2(248,3);
  v2(250,1)=24;
  v2(250,2)=5899;
  v2(250,3)=((1-exp(y(67)))*exp(y(68))-exp(y(67))*y(77))*(1-params(5))*(1-params(13))*T820;
  v2(251,1)=24;
  v2(251,2)=3820;
  v2(251,3)=  v2(250,3);
  v2(252,1)=24;
  v2(252,2)=5926;
  v2(252,3)=T310;
  v2(253,1)=24;
  v2(253,2)=5995;
  v2(253,3)=T740;
  v2(254,1)=24;
  v2(254,2)=5225;
  v2(254,3)=  v2(253,3);
  v2(255,1)=24;
  v2(255,2)=5977;
  v2(255,3)=(-exp(y(67)))*(1-params(5))*(1-params(13))*T820;
  v2(256,1)=24;
  v2(256,2)=3821;
  v2(256,3)=  v2(255,3);
  v2(257,1)=24;
  v2(257,2)=6004;
  v2(257,3)=T740;
  v2(258,1)=24;
  v2(258,2)=5927;
  v2(258,3)=  v2(257,3);
  v2(259,1)=25;
  v2(259,2)=949;
  v2(259,3)=exp(y(13));
  v2(260,1)=25;
  v2(260,2)=5215;
  v2(260,3)=exp(y(69))*T740;
  v2(261,1)=25;
  v2(261,2)=2055;
  v2(261,3)=(-exp(y(27)));
  v2(262,1)=25;
  v2(262,2)=5371;
  v2(262,3)=exp(y(69))*T740;
  v2(263,1)=25;
  v2(263,2)=5217;
  v2(263,3)=  v2(262,3);
  v2(264,1)=25;
  v2(264,2)=5373;
  v2(264,3)=T321;
  v2(265,1)=25;
  v2(265,2)=2134;
  v2(265,3)=(-exp(y(28)));
  v2(266,1)=25;
  v2(266,2)=3811;
  v2(266,3)=exp(y(69))*(-exp(y(67)))*(1-params(5))*(1-params(13))*T820;
  v2(267,1)=25;
  v2(267,2)=5197;
  v2(267,3)=  v2(266,3);
  v2(268,1)=25;
  v2(268,2)=3813;
  v2(268,3)=exp(y(69))*(1-exp(y(67)))*(1-params(5))*(1-params(13))*T820;
  v2(269,1)=25;
  v2(269,2)=5353;
  v2(269,3)=  v2(268,3);
  v2(270,1)=25;
  v2(270,2)=3793;
  v2(270,3)=exp(y(69))*(1-exp(y(67)))*(1-params(5))*(1-params(13))*T866;
  v2(271,1)=25;
  v2(271,2)=5917;
  v2(271,3)=exp(y(69))*T740;
  v2(272,1)=25;
  v2(272,2)=5224;
  v2(272,3)=  v2(271,3);
  v2(273,1)=25;
  v2(273,2)=5919;
  v2(273,3)=T321;
  v2(274,1)=25;
  v2(274,2)=5380;
  v2(274,3)=  v2(273,3);
  v2(275,1)=25;
  v2(275,2)=5899;
  v2(275,3)=exp(y(69))*(1-exp(y(67)))*(1-params(5))*(1-params(13))*T820;
  v2(276,1)=25;
  v2(276,2)=3820;
  v2(276,3)=  v2(275,3);
  v2(277,1)=25;
  v2(277,2)=5926;
  v2(277,3)=T321;
  v2(278,1)=26;
  v2(278,2)=1423;
  v2(278,3)=T336;
  v2(279,1)=26;
  v2(279,2)=5167;
  v2(279,3)=exp(y(69))*T334*(-exp(y(67)));
  v2(280,1)=26;
  v2(280,2)=1471;
  v2(280,3)=  v2(279,3);
  v2(281,1)=26;
  v2(281,2)=5215;
  v2(281,3)=exp(y(69))*T334*(-exp(y(67)));
  v2(282,1)=26;
  v2(282,2)=5323;
  v2(282,3)=T336;
  v2(283,1)=26;
  v2(283,2)=1473;
  v2(283,3)=  v2(282,3);
  v2(284,1)=26;
  v2(284,2)=5371;
  v2(284,3)=exp(y(69))*T334*(-exp(y(67)));
  v2(285,1)=26;
  v2(285,2)=5217;
  v2(285,3)=  v2(284,3);
  v2(286,1)=26;
  v2(286,2)=5373;
  v2(286,3)=T336;
  v2(287,1)=26;
  v2(287,2)=2134;
  v2(287,3)=(-exp(y(28)));
  v2(288,1)=26;
  v2(288,2)=3763;
  v2(288,3)=T838;
  v2(289,1)=26;
  v2(289,2)=1453;
  v2(289,3)=  v2(288,3);
  v2(290,1)=26;
  v2(290,2)=3811;
  v2(290,3)=exp(y(69))*(-exp(y(67)))*exp(y(19))*params(2)*(1-params(5))*(1-params(13))*T825;
  v2(291,1)=26;
  v2(291,2)=5197;
  v2(291,3)=  v2(290,3);
  v2(292,1)=26;
  v2(292,2)=3813;
  v2(292,3)=T838;
  v2(293,1)=26;
  v2(293,2)=5353;
  v2(293,3)=  v2(292,3);
  v2(294,1)=26;
  v2(294,2)=3793;
  v2(294,3)=exp(y(69))*(1-exp(y(67)))*exp(y(19))*params(2)*(1-params(5))*(1-params(13))*T929;
  v2(295,1)=26;
  v2(295,2)=5869;
  v2(295,3)=T336;
  v2(296,1)=26;
  v2(296,2)=1480;
  v2(296,3)=  v2(295,3);
  v2(297,1)=26;
  v2(297,2)=5917;
  v2(297,3)=exp(y(69))*T334*(-exp(y(67)));
  v2(298,1)=26;
  v2(298,2)=5224;
  v2(298,3)=  v2(297,3);
  v2(299,1)=26;
  v2(299,2)=5919;
  v2(299,3)=T336;
  v2(300,1)=26;
  v2(300,2)=5380;
  v2(300,3)=  v2(299,3);
  v2(301,1)=26;
  v2(301,2)=5899;
  v2(301,3)=T838;
  v2(302,1)=26;
  v2(302,2)=3820;
  v2(302,3)=  v2(301,3);
  v2(303,1)=26;
  v2(303,2)=5926;
  v2(303,3)=T336;
  v2(304,1)=26;
  v2(304,2)=4899;
  v2(304,3)=exp(y(63));
  v2(305,1)=27;
  v2(305,2)=870;
  v2(305,3)=(-exp(y(12)));
  v2(306,1)=27;
  v2(306,2)=1265;
  v2(306,3)=(T678*(-(exp(y(17))*exp(y(45))*exp(y(38))))-(-(exp(y(17))*exp(y(45))*exp(y(38))))*(T678+T678))/(T678*T678);
  v2(307,1)=27;
  v2(307,2)=2845;
  v2(307,3)=exp(y(44))*exp(y(37));
  v2(308,1)=27;
  v2(308,2)=2903;
  v2(308,3)=T690;
  v2(309,1)=27;
  v2(309,2)=1286;
  v2(309,3)=  v2(308,3);
  v2(310,1)=27;
  v2(310,2)=2924;
  v2(310,3)=T344+exp(y(44))*exp(y(38));
  v2(311,1)=27;
  v2(311,2)=3391;
  v2(311,3)=exp(y(44))*exp(y(37));
  v2(312,1)=27;
  v2(312,2)=2852;
  v2(312,3)=  v2(311,3);
  v2(313,1)=27;
  v2(313,2)=3392;
  v2(313,3)=exp(y(44))*exp(y(38));
  v2(314,1)=27;
  v2(314,2)=2930;
  v2(314,3)=  v2(313,3);
  v2(315,1)=27;
  v2(315,2)=3398;
  v2(315,3)=exp(y(44))*(exp(y(37))+exp(y(38)));
  v2(316,1)=27;
  v2(316,2)=3449;
  v2(316,3)=T690;
  v2(317,1)=27;
  v2(317,2)=1293;
  v2(317,3)=  v2(316,3);
  v2(318,1)=27;
  v2(318,2)=3470;
  v2(318,3)=T344;
  v2(319,1)=27;
  v2(319,2)=2931;
  v2(319,3)=  v2(318,3);
  v2(320,1)=27;
  v2(320,2)=3477;
  v2(320,3)=T344;
  v2(321,1)=28;
  v2(321,2)=791;
  v2(321,3)=T347;
  v2(322,1)=28;
  v2(322,2)=2819;
  v2(322,3)=(-(exp(y(11))*exp(y(37))))/T763;
  v2(323,1)=28;
  v2(323,2)=817;
  v2(323,3)=  v2(322,3);
  v2(324,1)=28;
  v2(324,2)=2845;
  v2(324,3)=(T763*(-(exp(y(11))*exp(y(37))))-(-(exp(y(11))*exp(y(37))))*(T763+T763))/(T763*T763);
  v2(325,1)=28;
  v2(325,2)=3477;
  v2(325,3)=(-exp(y(45)));
  v2(326,1)=29;
  v2(326,2)=1;
  v2(326,3)=T351;
  v2(327,1)=29;
  v2(327,2)=2809;
  v2(327,3)=(-(exp(y(1))*exp(y(37))))/T763;
  v2(328,1)=29;
  v2(328,2)=37;
  v2(328,3)=  v2(327,3);
  v2(329,1)=29;
  v2(329,2)=2845;
  v2(329,3)=(T763*(-(exp(y(1))*exp(y(37))))-(-(exp(y(1))*exp(y(37))))*(T763+T763))/(T763*T763);
  v2(330,1)=29;
  v2(330,2)=3556;
  v2(330,3)=(-exp(y(46)));
  v2(331,1)=30;
  v2(331,2)=870;
  v2(331,3)=T362*params(16)*(T616+exp(y(12))*exp(y(12))*getPowerDeriv(exp(y(12)),1-params(7),2));
  v2(332,1)=30;
  v2(332,2)=1344;
  v2(332,3)=(-exp(y(18)));
  v2(333,1)=30;
  v2(333,2)=1494;
  v2(333,3)=params(16)*T616*T697;
  v2(334,1)=30;
  v2(334,2)=878;
  v2(334,3)=  v2(333,3);
  v2(335,1)=30;
  v2(335,2)=1502;
  v2(335,3)=T361*(T697+exp(y(20))*exp(y(20))*getPowerDeriv(exp(y(20)),params(7),2));
  v2(336,1)=31;
  v2(336,2)=791;
  v2(336,3)=(-exp(y(11)));
  v2(337,1)=31;
  v2(337,2)=1502;
  v2(337,3)=(-exp(y(20)));
  v2(338,1)=32;
  v2(338,2)=1344;
  v2(338,3)=T371;
  v2(339,1)=32;
  v2(339,2)=1423;
  v2(339,3)=(-exp(y(19)));
  v2(340,1)=32;
  v2(340,2)=1500;
  v2(340,3)=T702;
  v2(341,1)=32;
  v2(341,2)=1346;
  v2(341,3)=  v2(340,3);
  v2(342,1)=32;
  v2(342,2)=1502;
  v2(342,3)=((-(exp(y(20))*exp(y(18))))*exp(y(20))*exp(y(20))-(-(exp(y(20))*exp(y(18))))*(exp(y(20))*exp(y(20))+exp(y(20))*exp(y(20))))/(exp(y(20))*exp(y(20))*exp(y(20))*exp(y(20)));
  v2(343,1)=33;
  v2(343,2)=870;
  v2(343,3)=((-(exp(y(12))*exp(y(18))))*exp(y(12))*exp(y(12))-(-(exp(y(12))*exp(y(18))))*(exp(y(12))*exp(y(12))+exp(y(12))*exp(y(12))))/(exp(y(12))*exp(y(12))*exp(y(12))*exp(y(12)));
  v2(344,1)=33;
  v2(344,2)=1265;
  v2(344,3)=(-exp(y(17)));
  v2(345,1)=33;
  v2(345,2)=1338;
  v2(345,3)=T622;
  v2(346,1)=33;
  v2(346,2)=876;
  v2(346,3)=  v2(345,3);
  v2(347,1)=33;
  v2(347,2)=1344;
  v2(347,3)=T375;
  v2(348,1)=34;
  v2(348,2)=1186;
  v2(348,3)=T436*T400*T655*(-(2*1.772453850905516*T657*T655*2*T416))/(T657*1.772453850905516*T657*1.772453850905516)/T384/T34;
  v2(349,1)=34;
  v2(349,2)=1654;
  v2(349,3)=(-((-exp(y(22)))*T664))/T722;
  v2(350,1)=34;
  v2(350,2)=1192;
  v2(350,3)=  v2(349,3);
  v2(351,1)=34;
  v2(351,2)=1660;
  v2(351,3)=(T722*(-(T438*(-exp(y(22)))))-(-(T438*(-exp(y(22)))))*(T34*(-exp(y(22)))+T34*(-exp(y(22)))))/(T722*T722);
  v2(352,1)=34;
  v2(352,2)=3872;
  v2(352,3)=(-exp(y(50)));
  v2(353,1)=35;
  v2(353,2)=1581;
  v2(353,3)=(-exp(y(21)));
  v2(354,1)=35;
  v2(354,2)=3872;
  v2(354,3)=T840+exp(y(50))*exp(y(50))*getPowerDeriv(exp(y(50)),(1-params(10))/params(20),2);
  v2(355,1)=36;
  v2(355,2)=1186;
  v2(355,3)=0.5*1/(params(9)*1.414213562373095)*(-(2*1.772453850905516*T668*1/(params(9)*1.414213562373095)*2*T449))/(1.772453850905516*T668*1.772453850905516*T668);
  v2(356,1)=36;
  v2(356,2)=1660;
  v2(356,3)=(-exp(y(22)));
  v2(357,1)=37;
  v2(357,2)=791;
  v2(357,3)=((-(exp(y(11))*exp(y(43))*(1-params(10))*exp(y(32))))*exp(y(11))*exp(y(11))-(-(exp(y(11))*exp(y(43))*(1-params(10))*exp(y(32))))*(exp(y(11))*exp(y(11))+exp(y(11))*exp(y(11))))/(exp(y(11))*exp(y(11))*exp(y(11))*exp(y(11)));
  v2(358,1)=37;
  v2(358,2)=1739;
  v2(358,3)=(-exp(y(23)));
  v2(359,1)=37;
  v2(359,2)=2429;
  v2(359,3)=T612;
  v2(360,1)=37;
  v2(360,2)=812;
  v2(360,3)=  v2(359,3);
  v2(361,1)=37;
  v2(361,2)=2450;
  v2(361,3)=T458;
  v2(362,1)=37;
  v2(362,2)=3287;
  v2(362,3)=T612;
  v2(363,1)=37;
  v2(363,2)=823;
  v2(363,3)=  v2(362,3);
  v2(364,1)=37;
  v2(364,2)=3308;
  v2(364,3)=T458;
  v2(365,1)=37;
  v2(365,2)=2461;
  v2(365,3)=  v2(364,3);
  v2(366,1)=37;
  v2(366,2)=3319;
  v2(366,3)=T458;
  v2(367,1)=38;
  v2(367,2)=1186;
  v2(367,3)=exp(y(23))*(T461*T673+T461*T1117);
  v2(368,1)=38;
  v2(368,2)=1576;
  v2(368,3)=exp(y(23))*(T712+T711*T1117);
  v2(369,1)=38;
  v2(369,2)=1191;
  v2(369,3)=  v2(368,3);
  v2(370,1)=38;
  v2(370,2)=1581;
  v2(370,3)=exp(y(23))*(T711*T711*T1116+T673*((-(exp(y(21))*exp(y(16))))*exp(y(21))*exp(y(21))-(-(exp(y(21))*exp(y(16))))*(exp(y(21))*exp(y(21))+exp(y(21))*exp(y(21))))/(exp(y(21))*exp(y(21))*exp(y(21))*exp(y(21))));
  v2(371,1)=38;
  v2(371,2)=1732;
  v2(371,3)=exp(y(23))*T461*T673;
  v2(372,1)=38;
  v2(372,2)=1193;
  v2(372,3)=  v2(371,3);
  v2(373,1)=38;
  v2(373,2)=1737;
  v2(373,3)=exp(y(23))*T712;
  v2(374,1)=38;
  v2(374,2)=1583;
  v2(374,3)=  v2(373,3);
  v2(375,1)=38;
  v2(375,2)=1739;
  v2(375,3)=T464;
  v2(376,1)=38;
  v2(376,2)=3951;
  v2(376,3)=(-exp(y(51)));
  v2(377,1)=39;
  v2(377,2)=1;
  v2(377,3)=((-(exp(y(1))*exp(y(43))*params(10)*exp(y(32))))*exp(y(1))*exp(y(1))-(-(exp(y(1))*exp(y(43))*params(10)*exp(y(32))))*(exp(y(1))*exp(y(1))+exp(y(1))*exp(y(1))))/(exp(y(1))*exp(y(1))*exp(y(1))*exp(y(1)));
  v2(378,1)=39;
  v2(378,2)=1818;
  v2(378,3)=(-exp(y(24)));
  v2(379,1)=39;
  v2(379,2)=2419;
  v2(379,3)=T632;
  v2(380,1)=39;
  v2(380,2)=32;
  v2(380,3)=  v2(379,3);
  v2(381,1)=39;
  v2(381,2)=2450;
  v2(381,3)=T470;
  v2(382,1)=39;
  v2(382,2)=3277;
  v2(382,3)=T632;
  v2(383,1)=39;
  v2(383,2)=43;
  v2(383,3)=  v2(382,3);
  v2(384,1)=39;
  v2(384,2)=3308;
  v2(384,3)=T470;
  v2(385,1)=39;
  v2(385,2)=2461;
  v2(385,3)=  v2(384,3);
  v2(386,1)=39;
  v2(386,2)=3319;
  v2(386,3)=T470;
  v2(387,1)=40;
  v2(387,2)=1897;
  v2(387,3)=exp(y(25));
  v2(388,1)=40;
  v2(388,2)=1976;
  v2(388,3)=(-exp(y(26)));
  v2(389,1)=41;
  v2(389,2)=1818;
  v2(389,3)=exp(y(24));
  v2(390,1)=41;
  v2(390,2)=2371;
  v2(390,3)=(-exp(y(31)));
  v2(391,1)=42;
  v2(391,2)=712;
  v2(391,3)=exp(y(10));
  v2(392,1)=42;
  v2(392,2)=791;
  v2(392,3)=(-(params(23)*(-exp(y(11)))));
  v2(393,1)=42;
  v2(393,2)=4109;
  v2(393,3)=(-exp(y(53)));
  v2(394,1)=43;
  v2(394,2)=712;
  v2(394,3)=T604+exp(y(10))*exp(y(10))*getPowerDeriv(exp(y(10)),(-params(1)),2);
  v2(395,1)=43;
  v2(395,2)=3793;
  v2(395,3)=(-exp(y(49)));
  v2(396,1)=45;
  v2(396,2)=4899;
  v2(396,3)=(-exp(y(63)));
  v2(397,1)=48;
  v2(397,2)=1660;
  v2(397,3)=(1-params(5))*exp(y(22))+(-exp(y(22)))*(1-params(5))*params(13);
  v2(398,1)=48;
  v2(398,2)=4030;
  v2(398,3)=(-exp(y(52)));
  v2(399,1)=49;
  v2(399,2)=791;
  v2(399,3)=exp(y(13))*exp(y(11));
  v2(400,1)=49;
  v2(400,2)=947;
  v2(400,3)=exp(y(13))*exp(y(11));
  v2(401,1)=49;
  v2(401,2)=793;
  v2(401,3)=  v2(400,3);
  v2(402,1)=49;
  v2(402,2)=949;
  v2(402,3)=exp(y(13))*exp(y(11));
  v2(403,1)=49;
  v2(403,2)=1;
  v2(403,3)=exp(y(1))*exp(y(31));
  v2(404,1)=49;
  v2(404,2)=2341;
  v2(404,3)=exp(y(1))*exp(y(31));
  v2(405,1)=49;
  v2(405,2)=31;
  v2(405,3)=  v2(404,3);
  v2(406,1)=49;
  v2(406,2)=2371;
  v2(406,3)=exp(y(1))*exp(y(31));
  v2(407,1)=49;
  v2(407,2)=2766;
  v2(407,3)=exp(y(36))*exp(y(37));
  v2(408,1)=49;
  v2(408,2)=2844;
  v2(408,3)=exp(y(36))*exp(y(37));
  v2(409,1)=49;
  v2(409,2)=2767;
  v2(409,3)=  v2(408,3);
  v2(410,1)=49;
  v2(410,2)=2845;
  v2(410,3)=exp(y(36))*exp(y(37));
  v2(411,1)=49;
  v2(411,2)=4346;
  v2(411,3)=(-exp(y(56)));
  v2(412,1)=50;
  v2(412,2)=2924;
  v2(412,3)=(params(18)+y(65))*exp(y(38));
  v2(413,1)=50;
  v2(413,2)=4188;
  v2(413,3)=(-exp(y(54)));
  v2(414,1)=50;
  v2(414,2)=5030;
  v2(414,3)=exp(y(38));
  v2(415,1)=50;
  v2(415,2)=2951;
  v2(415,3)=  v2(414,3);
  v2(416,1)=51;
  v2(416,2)=3003;
  v2(416,3)=(T786*(-(exp(y(39))*exp(y(56))))-(-(exp(y(39))*exp(y(56))))*(T786+T786))/(T786*T786);
  v2(417,1)=51;
  v2(417,2)=4329;
  v2(417,3)=(-(exp(y(39))*exp(y(56))))/T786;
  v2(418,1)=51;
  v2(418,2)=3020;
  v2(418,3)=  v2(417,3);
  v2(419,1)=51;
  v2(419,2)=4346;
  v2(419,3)=T546;
  v2(420,1)=51;
  v2(420,2)=4425;
  v2(420,3)=(-exp(y(57)));
  v2(421,1)=52;
  v2(421,2)=3003;
  v2(421,3)=(T786*(-(exp(y(39))*exp(y(53))))-(-(exp(y(39))*exp(y(53))))*(T786+T786))/(T786*T786);
  v2(422,1)=52;
  v2(422,2)=4095;
  v2(422,3)=(-(exp(y(39))*exp(y(53))))/T786;
  v2(423,1)=52;
  v2(423,2)=3017;
  v2(423,3)=  v2(422,3);
  v2(424,1)=52;
  v2(424,2)=4109;
  v2(424,3)=T552;
  v2(425,1)=52;
  v2(425,2)=4504;
  v2(425,3)=(-exp(y(58)));
  v2(426,1)=53;
  v2(426,2)=1107;
  v2(426,3)=T558;
  v2(427,1)=53;
  v2(427,2)=2979;
  v2(427,3)=(-(exp(y(39))*exp(y(15))))/T786;
  v2(428,1)=53;
  v2(428,2)=1131;
  v2(428,3)=  v2(427,3);
  v2(429,1)=53;
  v2(429,2)=3003;
  v2(429,3)=(T786*(-(exp(y(39))*exp(y(15))))-(-(exp(y(39))*exp(y(15))))*(T786+T786))/(T786*T786);
  v2(430,1)=53;
  v2(430,2)=4583;
  v2(430,3)=(-exp(y(59)));
  v2(431,1)=54;
  v2(431,2)=949;
  v2(431,3)=T564;
  v2(432,1)=54;
  v2(432,2)=2977;
  v2(432,3)=(-(exp(y(13))*exp(y(39))))/T786;
  v2(433,1)=54;
  v2(433,2)=975;
  v2(433,3)=  v2(432,3);
  v2(434,1)=54;
  v2(434,2)=3003;
  v2(434,3)=(T786*(-(exp(y(13))*exp(y(39))))-(-(exp(y(13))*exp(y(39))))*(T786+T786))/(T786*T786);
  v2(435,1)=54;
  v2(435,2)=4741;
  v2(435,3)=(-exp(y(61)));
  v2(436,1)=55;
  v2(436,2)=712;
  v2(436,3)=T570;
  v2(437,1)=55;
  v2(437,2)=2974;
  v2(437,3)=(-(exp(y(10))*exp(y(39))))/T786;
  v2(438,1)=55;
  v2(438,2)=741;
  v2(438,3)=  v2(437,3);
  v2(439,1)=55;
  v2(439,2)=3003;
  v2(439,3)=(T786*(-(exp(y(10))*exp(y(39))))-(-(exp(y(10))*exp(y(39))))*(T786+T786))/(T786*T786);
  v2(440,1)=55;
  v2(440,2)=4820;
  v2(440,3)=(-exp(y(62)));
  v2(441,1)=56;
  v2(441,2)=3003;
  v2(441,3)=(T786*(-(exp(y(39))*exp(y(54))))-(-(exp(y(39))*exp(y(54))))*(T786+T786))/(T786*T786);
  v2(442,1)=56;
  v2(442,2)=4173;
  v2(442,3)=(-(exp(y(39))*exp(y(54))))/T786;
  v2(443,1)=56;
  v2(443,2)=3018;
  v2(443,3)=  v2(442,3);
  v2(444,1)=56;
  v2(444,2)=4188;
  v2(444,3)=T576;
  v2(445,1)=56;
  v2(445,2)=4662;
  v2(445,3)=(-exp(y(60)));
  g2 = sparse(v2(:,1),v2(:,2),v2(:,3),56,6084);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],56,474552);
end
end
end
end
