// Endogenous Variables
var 
c                 // total consumption
l                 // aggregate employment
v                 // aggregate vacancies
w                 // wage
k                 // aggregate capital
ik                // investment in physical capital
zc                // job-productivity cutoff
q                 // probability of filling a vacancy
m                 // matches
s                 // job-finding probability
u                 // unemployment rate
zav               // average job productivity
rho               // endogenous separation rate
mpl               // marginal product of labor
mpk               // marginal product of capital
phi               // value of a match to the firm
surplusF          // firm surplus
surplusW          // worker surplus
oo                // value of unemployment
wzc               // wage marginal worker
y                 // aggregate output
rk                // real rate for capital
mc                // marginal cost
multR             // investment lagrange multiplier
adjI              // investment adjustment cost  
e                 // firm value
d                 // per-period firm profit
N                 // number of producers
Ne                // number of new entrants
rpD               // relative price 
elasticity        // elasticity of substitution
markup            // markup
yfirm             // firm output
yn                // firm production funtion
vfirm             // firm vacancies
lfirm             // firm employment
kfirm             // firm capital
Util              // household's utility
Welf              // household's welfare
uc                // marginal utility of consumption
zavInt            // integral to compute average job productivity
surplusFzc        // firm surplus from marginal job
surplusWzc        // marginal worker's surplus
phizc             // value of marginal worker to the firm
mplzc             // marginal product of marginal worker
cm                // market consumption
ie                // investment in new products 
z                 // aggregate productivity
gdpIncome         // GDP Income
gdpIncomedata     // GDP Income data-consistent
cmdata            // market consumption data-consistent
ikdata            // investment in physical capital data-consistent
iedata            // investment in new products data-consistent 
wdata             // wage data-consistent
cdata             // total consumption data-consistent
ub                // unemployment benefit
fc                // firing cost
fr                // sunk entry cost regulation
rrRateP
;
 
 
// Innovations
varexo epsZ epsR; 
 
parameters   gammaP betaP rhozP stdzP lambdaP etaP epsP meanziP stdziP alphaP piP adjIP deltafP  NbarP sigmaMuP chiP vcP fetechP deltakP shapeP exponenpfP fetechtarget hpP phiP chi,
           c_SSfin l_SSfin v_SSfin w_SSfin  k_SSfin ik_SSfin zc_SSfin q_SSfin m_SSfin s_SSfin u_SSfin zav_SSfin rho_SSfin mpl_SSfin mpk_SSfin phi_SSfin surplusF_SSfin surplusW_SSfin oo_SSfin wzc_SSfin y_SSfin rk_SSfin mc_SSfin multR_SSfin adjI_SSfin
           e_SSfin d_SSfin N_SSfin Ne_SSfin rpD_SSfin elasticity_SSfin markup_SSfin yfirm_SSfin yn_SSfin vfirm_SSfin lfirm_SSfin kfirm_SSfin uc_SSfin  zavInt_SSfin
           surplusFzc_SSfin surplusWzc_SSfin phizc_SSfin mplzc_SSfin cm_SSfin ub_SSfin fc_SSfin fr_SSfin z_SSfin gdpIncome_SSfin rrRatePfin
           c_SSinit l_SSinit  k_SSinit q_SSinit  N_SSinit Ne_SSinit z_SSinit  ik_SSinit c_SSinit lfirm_SSinit vfirm_SSinit  fr_SSinit ub_SSinit fc_SSinit w_SSinit rpD_SSinit gdpIncome_SSinit gdpIncomedata_SSinit rrRatePinit ub_SSinit;
 
 
set_parameters_from_file('steadyFinal',M_.param_names);
set_parameters_from_file('steadyInitial',M_.param_names);
set_parameters_from_file('calibration',M_.param_names);
 
//load phiP
//set_param_value('phiP',phiP); 

model(bytecode);
 
 
// %---Utility Function
//Util              = log(c);
 
Util                = log(c) - chi*(1-u)^2/2;
 
Welf              = Util + betaP*Welf(1);
 
 
//% Labor Market Block
- lfirm           + (1-lambdaP)*(1-rho)*lfirm(-1) + (1-lambdaP)*(1-rho)*q(-1)*vfirm(-1);
 
- vcP/q           + (1-lambdaP)*(1-deltafP)*(betaP*uc(1)/uc)*((1 - rho(1))*phi(1) - rho(1)*fc(1));  
 
- mplzc           + wzc - vcP/q  - fc;
 
- surplusF        + ( (1 - etaP)/etaP )*surplusW;
 
- surplusFzc      + ( (1 - etaP)/etaP )*surplusWzc;
 
- yn              + z*(zav^shapeP)*(k(-1)^alphaP)*(l^(1-alphaP));
 
//%% Entry Block
- d               + rpD*yfirm - w*lfirm - vcP*vfirm - mpk*kfirm - rho*lfirm*fc/(1-rho);  
 
- e               + (fetechP + fr) + vcP*(lfirm/q + vfirm);
 
- yfirm           + yn/N;
 
- rpD             + markup*mc;
 
- e               + (1 - deltafP)*betaP*(uc(1)/(uc))*(e(+1) + d(+1));
 
- N               + (1 - deltafP )*((N(-1)) + (Ne(-1)));
 
- 1               + rpD*((exp(.5*(NbarP - N)/(sigmaMuP*NbarP*N)))) ;
 
- markup          + elasticity/(elasticity - 1);
 
- elasticity      + ((1 + sigmaMuP*N));
 
- yfirm           + (1/rpD)*y/N;
 
- y               + cm + ik + vcP*v + Ne*(fetechP + fr) + rho*lfirm*N*fc/(1-rho);  
 
 
//%% Capital Accumulation 
 
- k               + (1 - deltakP)*k(-1)   +  ik*(1 - (adjIP/2)*(adjI^2));
 
- multR           + (betaP*uc(1)/uc)*(rk(1) + (1 - deltakP)*multR(1));
 
- 1               + multR*((1 - (adjIP/2)*(adjI^2))  -  adjIP*adjI*(ik/ik(-1)))  + adjIP*(betaP*uc(1)/uc)*multR(1)*(adjI(1)*((ik(1)/ik)^2));
 
- adjI            + ik/ik(-1) - 1;
 
 
//% Definitions (required to solve the model)
 
- phi             + mpl - w + (1-lambdaP)*(1-deltafP)*(betaP*uc(1)/uc)*( (1-rho(1))*phi(1) - rho(1)*fc(1) );  
 
- phizc           + mplzc - wzc + (1-lambdaP)*(1-deltafP)*(betaP*uc(1)/uc)*( (1-rho(1))*phi(1) - rho(1)*fc(1) ); 
 
- surplusW        + w - oo + (1-lambdaP)*(1-deltafP)*(betaP*uc(1)/uc)*(1-rho(1))*surplusW(1); 
 
- surplusWzc      + wzc - oo  + (1-lambdaP)*(1-deltafP)*(betaP*uc(1)/uc)*(1-rho(1))*surplusW(1); 
 
- oo              + hpP + ub  + (1-lambdaP)*(1-deltafP)*betaP*(uc(1)/uc)*(s)*(1-rho(1))*surplusW(1);
 
- v               + (N + Ne)*vfirm + Ne*lfirm/q ; 
 
- lfirm           + l/N; 
 
- kfirm           + k(-1)/N; 
 
- m               + (chiP*(v^(1-epsP))*(u^(epsP)));
 
- u               + 1     - l;
 
- s               + m/u;
 
- q               + m/v;
 
- zavInt          + (-1/2*piP^(1/2)*exp(1/2*(2*meanziP+stdziP^2*shapeP)*shapeP/(1-2*alphaP+alphaP^2))*(erf(1/2*2^(1/2)/stdziP*(-log(zc)+log(zc)*alphaP+stdziP^2*shapeP+meanziP-meanziP*alphaP)/(-1+alphaP))-erf(1/2*2^(1/2)*(-10000000000+10000000000*alphaP+stdziP^2*shapeP+meanziP-meanziP*alphaP)/stdziP/(-1+alphaP)))*exp(-shapeP*meanziP*alphaP/(-1+alphaP)^2)/piP^(1/2))/(1-rho);
 
- zav             + zavInt^((1 - alphaP)/shapeP);
 
- rho             + ((0.5 + 0.5 * erf((log(zc))/(stdziP*sqrt(2)))));
 
- mpl             + (1-alphaP)*mc*yn/l;
 
- mplzc           + mpl*(zc/zav)^exponenpfP;
 
- mpk             + alphaP*mc*yn/k(-1);
 
- surplusF        + phi + fc;
  
- surplusFzc      + phizc + fc;
 
- rk              + mpk;
 
- cm              + c - hpP*(1-l);
 
- uc              + c^-gammaP;
 
 
//% Exogenous Processes
- log(z)          + rhozP*log(z(-1)) + epsZ; 
 
//- ub              + ub_SSfin;
 
- ub                + ub_SSfin + phiP*(log(gdpIncome) - log(gdpIncome(-1)));

- fc              + fc_SSfin;
 
- fr              + fr_SSfin;
 
 
//% Additional variables (not needed to solve the model)
 
- gdpIncome       + w*l + rk*k(-1) + N*d;
 
- ie              + Ne*(fetechP + fr);
 
- gdpIncomedata   + gdpIncome/rpD;
 
- cmdata          + cm/rpD;
 
- ikdata          + ik/rpD;
 
- wdata           + w/rpD;
 
- cdata           + c/rpD;
 
- iedata          + ie/rpD;
 
- rrRateP         + ub/(w*rpD);
 
end;
 
 
initval;
z                   = z_SSfin;
ub                  = ub_SSfin;
fc                  = fc_SSfin;
fr                  = fr_SSfin;
c                   = c_SSfin; 
l                   = l_SSfin;
u                   = u_SSfin;
q                   = q_SSfin;
s                   = s_SSfin;
v                   = v_SSfin;
m                   = m_SSfin;
mc                  = mc_SSfin;
rho                 = rho_SSfin;
zavInt              = zavInt_SSfin;
zav                 = zav_SSfin;
zc                  = zc_SSfin;
surplusF            = surplusF_SSfin;
surplusW            = surplusW_SSfin;
oo                  = oo_SSfin;
phi                 = phi_SSfin;
ik                  = ik_SSfin;
rk                  = rk_SSfin;
mpk                 = mpk_SSfin;
mpl                 = mpl_SSfin;
y                   = y_SSfin;
k                   = k_SSfin;
adjI                = adjI_SSfin;
multR               = multR_SSfin;
e                   = e_SSfin;
d                   = d_SSfin;
N                   = N_SSfin;
Ne                  = Ne_SSfin;
rpD                 = rpD_SSfin;
elasticity          = elasticity_SSfin;
markup              = markup_SSfin;
yfirm               = yfirm_SSfin;
yn                  = yn_SSfin;
lfirm               = lfirm_SSfin;
kfirm               = kfirm_SSfin;
vfirm               = vfirm_SSfin;
//Util                = log(c) ;
Util                = log(c) - chi*(1-u)^2/2;
Welf                = (1/(1-betaP))*Util;
uc                  = (c)^-gammaP;
w                   = w_SSfin;
mplzc               = mpl*(zc/zav)^exponenpfP;
wzc                 = w - etaP*(mpl - mplzc); 
phizc               = mplzc - wzc + (1-lambdaP)*(1-deltafP)*betaP*( (1-rho)*phi - rho*fc);
surplusFzc          = phizc + fc;
surplusWzc          = wzc - oo + (1-lambdaP)*(1-deltafP)*betaP*(1-rho)*surplusW;
cm                  = cm_SSfin;
gdpIncome           = gdpIncome_SSfin;
cmdata              = cm/rpD;
gdpIncomedata       = gdpIncome/rpD;
ikdata              = ik/rpD;
wdata               = w/rpD;
cdata               = c/rpD;
ie                  = Ne*(fetechP + fr);
iedata              = ie/rpD;
rrRateP             = ub/(w*rpD);
end;
 
 
resid(1);
 
if max(abs(resid))>1e-10
    display('RESIDUALS IN TRANSITION.MOD FILE ARE NOT ZERO')
    keyboard
end
 
 
shocks;
var epsR;       periods 1:1     ; values 1;
end;
 
 
histval;
k(0)         = k_SSinit;
q(0)         = q_SSinit;
N(0)         = N_SSinit;
Ne(0)        = Ne_SSinit;
z(0)         = z_SSinit;
ik(0)        = ik_SSinit;
lfirm(0)     = lfirm_SSinit;
vfirm(0)     = vfirm_SSinit;
gdpIncome(0) = gdpIncome_SSinit;
end;
 
options_.dynatol.f   = 1e-10;
options_.periods     = 500;
options_.simul.maxit = 800;
simul(stack_solve_algo = 4);
 
 
initplot = 2;
endplot  = 40;
 

load steadyInitial;
 
figure(1);
subplot(2,4,1);
plot(100*(c(initplot:endplot)/c_SSinit - 1),'b','Linewidth',2);axis tight;grid on; title('Consumption');
subplot(2,4,2);
plot(100*(u(initplot:endplot) - u_SSinit),'b','Linewidth',2);axis tight;grid on; title('Unemployment rate');
subplot(2,4,3);
plot(100*(ikdata(initplot:endplot)/(ik_SSinit/rpD_SSinit) - 1),'b','Linewidth',2);axis tight;grid on; title('Investment physical capital');
subplot(2,4,4);
plot(100*(gdpIncomedata(initplot:endplot)/(gdpIncome_SSinit/rpD_SSinit) - 1),'b','Linewidth',2);axis tight;grid on; title('GDP');
subplot(2,4,5);
plot(100*(markup(initplot:endplot)/markup_SSinit - 1),'b','Linewidth',2);axis tight;grid on; title('Markup');
subplot(2,4,6);
plot(100*(N(initplot:endplot)/N_SSinit - 1),'b','Linewidth',2);grid on;axis tight, title('Producers');
subplot(2,4,7);
plot(100*(iedata(initplot:endplot)/(Ne_SSinit*(fr_SSinit + fetechP)/rpD_SSinit)-1),'b','Linewidth',2);axis tight;grid on; title('Investment new products');
subplot(2,4,8);
plot(100*(yfirm(initplot:endplot)/yfirm_SSinit - 1),'b','Linewidth',2);axis tight;grid on; title('Firm Size');

/*
*/ 

